@@ -123,6 +123,10 @@ static void AskForBackup(obs_data_t *obj);
 
 static void SaveSceneSwitcher(obs_data_t *save_data, bool saving, void *)
 {
+	if (!switcher) {
+		return;
+	}
+
 	if (saving) {
 		std::lock_guard<std::mutex> lock(switcher->m);
 		switcher->Prune();
@@ -439,6 +443,8 @@ void SwitcherData::Start()
 	}
 }
 
+bool CloseAllInputDialogs();
+
 void SwitcherData::Stop()
 {
 	if (th && th->isRunning()) {
@@ -447,10 +453,23 @@ void SwitcherData::Stop()
 		abortMacroWait = true;
 		macroWaitCv.notify_all();
 		macroTransitionCv.notify_all();
-		th->wait();
-		delete th;
-		th = nullptr;
 
+		// Not waiting if a dialog was closed is a workaround to avoid
+		// deadlocks when a variable input dialog is opened while Stop()
+		// is called.
+		//
+		// The QEventLoop handling the dialog would not exit until Stop()
+		// would return, which itself would wait for the switcher thread
+		// to complete, which itself is blocked by the variable input
+		// dialog.
+		//
+		// Must be reworked in the future, as this will not go well when
+		// OBS is shutting down and a dialog is still opened.
+		if (!CloseAllInputDialogs()) {
+			th->wait();
+			delete th;
+			th = nullptr;
+		}
 		writeToStatusFile("Advanced Scene Switcher stopped");
 	}
 
@@ -599,7 +618,7 @@ static void setStreamStopping()
 		std::chrono::high_resolution_clock::now();
 }
 
-static void handleExit()
+static void handleShutdown()
 {
 	if (!switcher) {
 		return;
@@ -609,8 +628,14 @@ static void handleExit()
 		switcher->Stop();
 		switcher->CheckMacros();
 		switcher->RunMacros();
+
+		// Unfortunately this will not work as OBS will now allow saving
+		// the scene collection data at this point, So any OBS specific
+		// changes done during shutdown will be lost
+		//
+		// TODO: Look for a way to possibly resolve this
+		obs_frontend_save();
 	}
-	FreeSceneSwitcher();
 }
 
 static void handleSceneCollectionChanging()
@@ -634,8 +659,12 @@ static void OBSEvent(enum obs_frontend_event event, void *switcher)
 	}
 
 	switch (event) {
-	case OBS_FRONTEND_EVENT_EXIT:
-		handleExit();
+	case OBS_FRONTEND_EVENT_SCRIPTING_SHUTDOWN:
+		// Note: We are intentionally not listening for
+		// OBS_FRONTEND_EVENT_EXIT here as at that point all scene
+		// collection data will already have been cleared and thus all
+		// macros will have already been cleared
+		handleShutdown();
 		break;
 	case OBS_FRONTEND_EVENT_SCENE_CHANGED:
 		handleSceneChange();
@@ -673,6 +702,9 @@ static void OBSEvent(enum obs_frontend_event event, void *switcher)
 	case OBS_FRONTEND_EVENT_SCENE_COLLECTION_CHANGING:
 		handleSceneCollectionChanging();
 		break;
+	case OBS_FRONTEND_EVENT_SCENE_COLLECTION_CLEANUP:
+		SaveSceneSwitcher(nullptr, false, nullptr);
+		break;
 #endif
 	default:
 		break;
