@@ -1,9 +1,12 @@
 #include "hotkey.hpp"
 #include "advanced-scene-switcher.hpp"
+#include "switcher-data.hpp"
 #include <obs-module.h>
 #include <fstream>
 #include <regex>
 
+namespace advss {
+
 std::vector<std::weak_ptr<Hotkey>> Hotkey::_registeredHotkeys = {};
 uint32_t Hotkey::_hotkeyCounter = 1;
 
@@ -117,7 +120,7 @@ void Hotkey::ClearAllHotkeys()
 	_registeredHotkeys.clear();
 }
 
-void startHotkeyFunc(void *, obs_hotkey_id, obs_hotkey_t *, bool pressed)
+static void startHotkeyFunc(void *, obs_hotkey_id, obs_hotkey_t *, bool pressed)
 {
 	if (pressed) {
 		if (!(switcher->th && switcher->th->isRunning())) {
@@ -126,7 +129,7 @@ void startHotkeyFunc(void *, obs_hotkey_id, obs_hotkey_t *, bool pressed)
 	}
 }
 
-void stopHotkeyFunc(void *, obs_hotkey_id, obs_hotkey_t *, bool pressed)
+static void stopHotkeyFunc(void *, obs_hotkey_id, obs_hotkey_t *, bool pressed)
 {
 	if (pressed) {
 		if (switcher->th && switcher->th->isRunning()) {
@@ -135,8 +138,8 @@ void stopHotkeyFunc(void *, obs_hotkey_id, obs_hotkey_t *, bool pressed)
 	}
 }
 
-void startStopToggleHotkeyFunc(void *, obs_hotkey_id, obs_hotkey_t *,
-			       bool pressed)
+static void startStopToggleHotkeyFunc(void *, obs_hotkey_id, obs_hotkey_t *,
+				      bool pressed)
 {
 	if (pressed) {
 		if (switcher->th && switcher->th->isRunning()) {
@@ -147,8 +150,8 @@ void startStopToggleHotkeyFunc(void *, obs_hotkey_id, obs_hotkey_t *,
 	}
 }
 
-void upMacroSegmentHotkeyFunc(void *, obs_hotkey_id, obs_hotkey_t *,
-			      bool pressed)
+static void upMacroSegmentHotkeyFunc(void *, obs_hotkey_id, obs_hotkey_t *,
+				     bool pressed)
 {
 	if (pressed && switcher->settingsWindowOpened &&
 	    AdvSceneSwitcher::window) {
@@ -158,8 +161,8 @@ void upMacroSegmentHotkeyFunc(void *, obs_hotkey_id, obs_hotkey_t *,
 	}
 }
 
-void downMacroSegmentHotkeyFunc(void *, obs_hotkey_id, obs_hotkey_t *,
-				bool pressed)
+static void downMacroSegmentHotkeyFunc(void *, obs_hotkey_id, obs_hotkey_t *,
+				       bool pressed)
 {
 	if (pressed && switcher->settingsWindowOpened &&
 	    AdvSceneSwitcher::window) {
@@ -169,8 +172,8 @@ void downMacroSegmentHotkeyFunc(void *, obs_hotkey_id, obs_hotkey_t *,
 	}
 }
 
-void removeMacroSegmentHotkeyFunc(void *, obs_hotkey_id, obs_hotkey_t *,
-				  bool pressed)
+static void removeMacroSegmentHotkeyFunc(void *, obs_hotkey_id, obs_hotkey_t *,
+					 bool pressed)
 {
 	if (pressed && switcher->settingsWindowOpened &&
 	    AdvSceneSwitcher::window) {
@@ -180,7 +183,7 @@ void removeMacroSegmentHotkeyFunc(void *, obs_hotkey_id, obs_hotkey_t *,
 	}
 }
 
-void registerHotkeys()
+static void registerHotkeys()
 {
 	switcher->startHotkey = obs_hotkey_register_frontend(
 		"startSwitcherHotkey",
@@ -213,14 +216,14 @@ void registerHotkeys()
 	switcher->hotkeysRegistered = true;
 }
 
-void saveHotkey(obs_data_t *obj, obs_hotkey_id id, const char *name)
+static void saveHotkey(obs_data_t *obj, obs_hotkey_id id, const char *name)
 {
 	obs_data_array_t *a = obs_hotkey_save(id);
 	obs_data_set_array(obj, name, a);
 	obs_data_array_release(a);
 }
 
-void SwitcherData::saveHotkeys(obs_data_t *obj)
+void SwitcherData::SaveHotkeys(obs_data_t *obj)
 {
 	saveHotkey(obj, startHotkey, "startHotkey");
 	saveHotkey(obj, stopHotkey, "stopHotkey");
@@ -230,14 +233,14 @@ void SwitcherData::saveHotkeys(obs_data_t *obj)
 	saveHotkey(obj, removeMacroSegment, "removeMacroSegmentHotkey");
 }
 
-void loadHotkey(obs_data_t *obj, obs_hotkey_id id, const char *name)
+static void loadHotkey(obs_data_t *obj, obs_hotkey_id id, const char *name)
 {
 	obs_data_array_t *a = obs_data_get_array(obj, name);
 	obs_hotkey_load(id, a);
 	obs_data_array_release(a);
 }
 
-void SwitcherData::loadHotkeys(obs_data_t *obj)
+void SwitcherData::LoadHotkeys(obs_data_t *obj)
 {
 	if (!hotkeysRegistered) {
 		registerHotkeys();
@@ -249,3 +252,5 @@ void SwitcherData::loadHotkeys(obs_data_t *obj)
 	loadHotkey(obj, downMacroSegment, "downMacroSegmentHotkey");
 	loadHotkey(obj, removeMacroSegment, "removeMacroSegmentHotkey");
 }
+
+} // namespace advss
