@@ -1,3 +1,8 @@
+#include "advanced-scene-switcher.hpp"
+#include "switcher-data.hpp"
+#include "curl-helper.hpp"
+#include "utility.hpp"
+
 #include <QtGlobal>
 #include <QFileDialog>
 #include <QTextStream>
@@ -6,9 +11,7 @@
 #include <regex>
 #include <curl/curl.h>
 
-#include "advanced-scene-switcher.hpp"
-#include "curl-helper.hpp"
-#include "utility.hpp"
+namespace advss {
 
 bool FileSwitch::pause = false;
 static QMetaObject::Connection addPulse;
@@ -209,7 +212,7 @@ bool matchFileContent(QString &filedata, FileSwitch &s)
 	}
 
 	QString text = QString::fromStdString(s.text);
-	return compareIgnoringLineEnding(text, filedata);
+	return CompareIgnoringLineEnding(text, filedata);
 }
 
 bool checkRemoteFileContent(FileSwitch &s)
@@ -411,7 +414,7 @@ void SwitcherData::loadFileSwitches(obs_data_t *obj)
 	fileIO.writePath = obs_data_get_string(obj, "writePath");
 }
 
-void AdvSceneSwitcher::setupFileTab()
+void AdvSceneSwitcher::SetupFileTab()
 {
 	ui->remoteFileWarningLabel->setText(
 		obs_module_text("AdvSceneSwitcher.fileTab.remoteFileWarning1") +
@@ -542,11 +545,11 @@ FileSwitchWidget::FileSwitchWidget(QWidget *parent, FileSwitch *s)
 	QHBoxLayout *line1Layout = new QHBoxLayout;
 	QHBoxLayout *line2Layout = new QHBoxLayout;
 	QHBoxLayout *line3Layout = new QHBoxLayout;
-	placeWidgets(obs_module_text("AdvSceneSwitcher.fileTab.entry"),
+	PlaceWidgets(obs_module_text("AdvSceneSwitcher.fileTab.entry"),
 		     line1Layout, widgetPlaceholders);
-	placeWidgets(obs_module_text("AdvSceneSwitcher.fileTab.entry2"),
+	PlaceWidgets(obs_module_text("AdvSceneSwitcher.fileTab.entry2"),
 		     line2Layout, widgetPlaceholders, false);
-	placeWidgets(obs_module_text("AdvSceneSwitcher.fileTab.entry3"),
+	PlaceWidgets(obs_module_text("AdvSceneSwitcher.fileTab.entry3"),
 		     line3Layout, widgetPlaceholders);
 	mainLayout->addLayout(line1Layout);
 	mainLayout->addLayout(line2Layout);
@@ -665,3 +668,5 @@ void FileSwitchWidget::CheckFileContentChanged(int state)
 	std::lock_guard<std::mutex> lock(switcher->m);
 	switchData->onlyMatchIfChanged = state;
 }
+
+} // namespace advss
