@@ -7,8 +7,12 @@ Most of this code is based on https://github.com/Palakis/obs-websocket
 #include <QMessageBox>
 
 #include "advanced-scene-switcher.hpp"
+#include "switcher-data.hpp"
+#include "scene-switch-helpers.hpp"
 #include "utility.hpp"
 
+namespace advss {
+
 #define PARAM_SERVER_ENABLE "ServerEnabled"
 #define PARAM_SERVER_PORT "ServerPort"
 #define PARAM_LOCKTOIPV4 "LockToIPv4"
@@ -124,10 +128,9 @@ WSServer::WSServer() : QObject(nullptr), _connections(), _clMutex()
 	_server.set_reuse_addr(true);
 #endif
 
-	_server.set_open_handler(bind(&WSServer::onOpen, this, ::_1));
-	_server.set_close_handler(bind(&WSServer::onClose, this, ::_1));
-	_server.set_message_handler(
-		bind(&WSServer::onMessage, this, ::_1, ::_2));
+	_server.set_open_handler(bind(&WSServer::onOpen, this, _1));
+	_server.set_close_handler(bind(&WSServer::onClose, this, _1));
+	_server.set_message_handler(bind(&WSServer::onMessage, this, _1, _2));
 }
 
 WSServer::~WSServer()
@@ -221,7 +224,7 @@ void WSServer::stop()
 	blog(LOG_INFO, "server stopped successfully");
 }
 
-void WSServer::sendMessage(sceneSwitchInfo sceneSwitch, bool preview)
+void WSServer::sendMessage(SceneSwitchInfo sceneSwitch, bool preview)
 {
 	if (!sceneSwitch.scene) {
 		return;
@@ -305,9 +308,9 @@ std::string processMessage(std::string payload)
 		       "'";
 	}
 	if (preview) {
-		switchPreviewScene(scene);
+		SwitchPreviewScene(scene);
 	} else {
-		switchScene({scene, transition, duration});
+		SwitchScene({scene, transition, duration});
 	}
 	return ret;
 }
@@ -361,11 +364,10 @@ WSClient::WSClient() : QObject(nullptr)
 	_client.set_reuse_addr(true);
 #endif
 
-	_client.set_open_handler(bind(&WSClient::onOpen, this, ::_1));
-	_client.set_fail_handler(bind(&WSClient::onFail, this, ::_1));
-	_client.set_message_handler(
-		bind(&WSClient::onMessage, this, ::_1, ::_2));
-	_client.set_close_handler(bind(&WSClient::onClose, this, ::_1));
+	_client.set_open_handler(bind(&WSClient::onOpen, this, _1));
+	_client.set_fail_handler(bind(&WSClient::onFail, this, _1));
+	_client.set_message_handler(bind(&WSClient::onMessage, this, _1, _2));
+	_client.set_close_handler(bind(&WSClient::onClose, this, _1));
 }
 
 WSClient::~WSClient()
@@ -501,7 +503,7 @@ void SwitcherData::saveNetworkSwitches(obs_data_t *obj)
 	}
 }
 
-void AdvSceneSwitcher::setupNetworkTab()
+void AdvSceneSwitcher::SetupNetworkTab()
 {
 	ui->serverSettings->setChecked(switcher->networkConfig.ServerEnabled);
 	ui->serverPort->setValue(switcher->networkConfig.ServerPort);
@@ -519,9 +521,9 @@ void AdvSceneSwitcher::setupNetworkTab()
 
 	QTimer *statusTimer = new QTimer(this);
 	connect(statusTimer, SIGNAL(timeout()), this,
-		SLOT(updateClientStatus()));
+		SLOT(UpdateClientStatus()));
 	connect(statusTimer, SIGNAL(timeout()), this,
-		SLOT(updateServerStatus()));
+		SLOT(UpdateServerStatus()));
 	statusTimer->start(500);
 }
 
@@ -572,7 +574,7 @@ void AdvSceneSwitcher::on_serverRestart_clicked()
 			       switcher->networkConfig.LockToIPv4);
 }
 
-void AdvSceneSwitcher::updateServerStatus()
+void AdvSceneSwitcher::UpdateServerStatus()
 {
 	switch (switcher->serverStatus) {
 	case ServerStatus::NOT_RUNNING:
@@ -670,7 +672,7 @@ void AdvSceneSwitcher::on_clientReconnect_clicked()
 	switcher->client.connect(switcher->networkConfig.GetClientUri());
 }
 
-void AdvSceneSwitcher::updateClientStatus()
+void AdvSceneSwitcher::UpdateClientStatus()
 {
 	switch (switcher->clientStatus) {
 	case ClientStatus::DISCONNECTED:
@@ -709,3 +711,5 @@ Compatability::StdFunctionRunnable::StdFunctionRunnable(
 	: cb(std::move(func))
 {
 }
+
+} // namespace advss
