@@ -1,9 +1,12 @@
+#include "advanced-scene-switcher.hpp"
+#include "switcher-data.hpp"
+#include "utility.hpp"
+
 #include <QFileDialog>
 #include <QTextStream>
 #include <QScrollArea>
 
-#include "advanced-scene-switcher.hpp"
-#include "utility.hpp"
+namespace advss {
 
 constexpr auto max_extend_text_size = 150;
 
@@ -278,7 +281,7 @@ void SwitcherData::loadSceneSequenceSwitches(obs_data_t *obj)
 	obs_data_array_release(sceneSequenceArray);
 }
 
-void AdvSceneSwitcher::setupSequenceTab()
+void AdvSceneSwitcher::SetupSequenceTab()
 {
 	for (auto &s : switcher->sceneSequenceSwitches) {
 		QListWidgetItem *item;
@@ -455,7 +458,7 @@ bool SceneSequenceSwitch::checkDurationMatchInterruptible()
 
 void SceneSequenceSwitch::prepareUninterruptibleMatch(int &linger)
 {
-	int dur = delay.seconds * 1000;
+	int dur = delay.Milliseconds();
 	if (dur > 0) {
 		linger = dur;
 	}
@@ -588,10 +591,8 @@ SequenceWidget::SequenceWidget(QWidget *parent, SceneSequenceSwitch *s,
 	QWidget::connect(scenes, SIGNAL(currentTextChanged(const QString &)),
 			 this, SLOT(SceneChanged(const QString &)));
 
-	QWidget::connect(delay, SIGNAL(DurationChanged(double)), this,
-			 SLOT(DelayChanged(double)));
-	QWidget::connect(delay, SIGNAL(UnitChanged(DurationUnit)), this,
-			 SLOT(DelayUnitsChanged(DurationUnit)));
+	QWidget::connect(delay, SIGNAL(DurationChanged(const Duration &)), this,
+			 SLOT(DelayChanged(const Duration &)));
 	QWidget::connect(startScenes,
 			 SIGNAL(currentTextChanged(const QString &)), this,
 			 SLOT(StartSceneChanged(const QString &)));
@@ -603,7 +604,7 @@ SequenceWidget::SequenceWidget(QWidget *parent, SceneSequenceSwitch *s,
 	QWidget::connect(reduce, SIGNAL(clicked()), this,
 			 SLOT(ReduceClicked()));
 
-	populateSceneSelection(startScenes);
+	PopulateSceneSelection(startScenes);
 	interruptible->setToolTip(obs_module_text(
 		"AdvSceneSwitcher.sceneSequenceTab.interruptibleHint"));
 
@@ -615,7 +616,7 @@ SequenceWidget::SequenceWidget(QWidget *parent, SceneSequenceSwitch *s,
 			{"{{scenes}}", scenes},
 			{"{{delay}}", delay},
 			{"{{transitions}}", transitions}};
-		placeWidgets(
+		PlaceWidgets(
 			obs_module_text(
 				"AdvSceneSwitcher.sceneSequenceTab.extendEntry"),
 			mainLayout, widgetPlaceholders);
@@ -628,7 +629,7 @@ SequenceWidget::SequenceWidget(QWidget *parent, SceneSequenceSwitch *s,
 			{"{{delay}}", delay},
 			{"{{transitions}}", transitions},
 			{"{{interruptible}}", interruptible}};
-		placeWidgets(obs_module_text(
+		PlaceWidgets(obs_module_text(
 				     "AdvSceneSwitcher.sceneSequenceTab.entry"),
 			     startSequence, widgetPlaceholders);
 
@@ -689,24 +690,14 @@ void SequenceWidget::swapSwitchData(SequenceWidget *s1, SequenceWidget *s2)
 	s2->setSwitchData(t);
 }
 
-void SequenceWidget::DelayChanged(double sec)
+void SequenceWidget::DelayChanged(const Duration &delay)
 {
 	if (loading || !switchData) {
 		return;
 	}
 
 	std::lock_guard<std::mutex> lock(switcher->m);
-	switchData->delay.seconds = sec;
-}
-
-void SequenceWidget::DelayUnitsChanged(DurationUnit unit)
-{
-	if (loading || !switchData) {
-		return;
-	}
-
-	std::lock_guard<std::mutex> lock(switcher->m);
-	switchData->delay.displayUnit = unit;
+	switchData->delay = delay;
 }
 
 void SequenceWidget::setExtendedSequenceStartScene()
@@ -805,3 +796,5 @@ void SequenceWidget::ReduceClicked()
 		delete item;
 	}
 }
+
+} // namespace advss
