@@ -1,7 +1,10 @@
+#include "advanced-scene-switcher.hpp"
+#include "switcher-data.hpp"
+#include "utility.hpp"
+
 #include <thread>
 
-#include "advanced-scene-switcher.hpp"
-#include "utility.hpp"
+namespace advss {
 
 constexpr auto default_def_transition_dealy = 300;
 bool DefaultSceneTransition::pause = false;
@@ -169,7 +172,7 @@ void SwitcherData::checkDefaultSceneTransitions()
 	}
 }
 
-void AdvSceneSwitcher::defTransitionDelayValueChanged(int value)
+void AdvSceneSwitcher::DefTransitionDelayValueChanged(int value)
 {
 	if (loading) {
 		return;
@@ -179,104 +182,6 @@ void AdvSceneSwitcher::defTransitionDelayValueChanged(int value)
 	DefaultSceneTransition::delay = value;
 }
 
-std::pair<obs_weak_source_t *, int> getNextTransition(obs_weak_source_t *scene1,
-						      obs_weak_source_t *scene2)
-{
-	obs_weak_source_t *ws = nullptr;
-	int duration = 0;
-	if (scene1 && scene2) {
-		for (SceneTransition &t : switcher->sceneTransitions) {
-			if (!t.initialized()) {
-				continue;
-			}
-
-			if (t.scene == scene1 && t.scene2 == scene2) {
-				ws = t.transition;
-				duration = t.duration * 1000;
-				break;
-			}
-		}
-	}
-	return std::make_pair(ws, duration);
-}
-
-void overwriteTransitionOverride(const sceneSwitchInfo &ssi, transitionData &td)
-{
-	obs_source_t *scene = obs_weak_source_get_source(ssi.scene);
-	obs_data_t *data = obs_source_get_private_settings(scene);
-
-	td.name = obs_data_get_string(data, "transition");
-	td.duration = obs_data_get_int(data, "transition_duration");
-
-	std::string name = GetWeakSourceName(ssi.transition);
-
-	obs_data_set_string(data, "transition", name.c_str());
-	obs_data_set_int(data, "transition_duration", ssi.duration);
-
-	obs_data_release(data);
-	obs_source_release(scene);
-}
-
-void restoreTransitionOverride(obs_source_t *scene, const transitionData &td)
-{
-	obs_data_t *data = obs_source_get_private_settings(scene);
-
-	obs_data_set_string(data, "transition", td.name.c_str());
-	obs_data_set_int(data, "transition_duration", td.duration);
-
-	obs_data_release(data);
-}
-
-void setNextTransition(const sceneSwitchInfo &sceneSwitch,
-		       obs_source_t *currentSource, transitionData &td)
-{
-	// Priority:
-	// 1. Transition tab
-	// 2. Individual switcher entry
-	// 3. Current transition settings
-
-	// Transition Tab
-	obs_weak_source_t *currentScene =
-		obs_source_get_weak_source(currentSource);
-	auto tinfo = getNextTransition(currentScene, sceneSwitch.scene);
-	obs_weak_source_release(currentScene);
-
-	OBSWeakSource nextTransition = tinfo.first;
-	int nextTransitionDuration = tinfo.second;
-
-	// Individual switcher entry
-	if (!nextTransition) {
-		nextTransition = sceneSwitch.transition;
-	}
-	if (!nextTransitionDuration) {
-		nextTransitionDuration = sceneSwitch.duration;
-	}
-
-	// Current transition settings
-	if (!nextTransition) {
-		auto ct = obs_frontend_get_current_transition();
-		nextTransition = obs_source_get_weak_source(ct);
-		obs_weak_source_release(nextTransition);
-		obs_source_release(ct);
-	}
-	if (!nextTransitionDuration) {
-		nextTransitionDuration = obs_frontend_get_transition_duration();
-	}
-
-	if (switcher->adjustActiveTransitionType) {
-		obs_frontend_set_transition_duration(nextTransitionDuration);
-		auto t = obs_weak_source_get_source(nextTransition);
-		obs_frontend_set_current_transition(t);
-		obs_source_release(t);
-	}
-
-	if (switcher->transitionOverrideOverride) {
-		overwriteTransitionOverride({sceneSwitch.scene, nextTransition,
-					     nextTransitionDuration},
-					    td);
-	}
-}
-
 void SwitcherData::saveSceneTransitions(obs_data_t *obj)
 {
 	obs_data_array_t *sceneTransitionsArray = obs_data_array_create();
@@ -349,7 +254,7 @@ void SwitcherData::loadSceneTransitions(obs_data_t *obj)
 		obs_data_get_int(obj, "defTransitionDelay");
 }
 
-void AdvSceneSwitcher::setupTransitionsTab()
+void AdvSceneSwitcher::SetupTransitionsTab()
 {
 	for (auto &s : switcher->sceneTransitions) {
 		QListWidgetItem *item;
@@ -397,11 +302,11 @@ void AdvSceneSwitcher::setupTransitionsTab()
 		"AdvSceneSwitcher.transitionTab.defaultTransition.delay.help"));
 
 	QWidget::connect(defTransitionDelay, SIGNAL(valueChanged(int)), this,
-			 SLOT(defTransitionDelayValueChanged(int)));
+			 SLOT(DefTransitionDelayValueChanged(int)));
 
 	std::unordered_map<std::string, QWidget *> widgetPlaceholders = {
 		{"{{defTransitionDelay}}", defTransitionDelay}};
-	placeWidgets(
+	PlaceWidgets(
 		obs_module_text(
 			"AdvSceneSwitcher.transitionTab.defaultTransition.delay"),
 		ui->defTransitionDelayLayout, widgetPlaceholders);
@@ -449,7 +354,7 @@ TransitionSwitchWidget::TransitionSwitchWidget(QWidget *parent,
 	QWidget::connect(duration, SIGNAL(valueChanged(double)), this,
 			 SLOT(DurationChanged(double)));
 
-	populateSceneSelection(scenes2);
+	PopulateSceneSelection(scenes2);
 
 	if (s) {
 		scenes2->setCurrentText(GetWeakSourceName(s->scene2).c_str());
@@ -462,7 +367,7 @@ TransitionSwitchWidget::TransitionSwitchWidget(QWidget *parent,
 		{"{{scenes2}}", scenes2},
 		{"{{duration}}", duration},
 		{"{{transitions}}", transitions}};
-	placeWidgets(obs_module_text("AdvSceneSwitcher.transitionTab.entry"),
+	PlaceWidgets(obs_module_text("AdvSceneSwitcher.transitionTab.entry"),
 		     mainLayout, widgetPlaceholders);
 	setLayout(mainLayout);
 
@@ -518,7 +423,7 @@ DefTransitionSwitchWidget::DefTransitionSwitchWidget(QWidget *parent,
 	QHBoxLayout *mainLayout = new QHBoxLayout;
 	std::unordered_map<std::string, QWidget *> widgetPlaceholders = {
 		{"{{scenes}}", scenes}, {"{{transitions}}", transitions}};
-	placeWidgets(
+	PlaceWidgets(
 		obs_module_text(
 			"AdvSceneSwitcher.transitionTab.defaultTransitionEntry"),
 		mainLayout, widgetPlaceholders);
@@ -592,3 +497,5 @@ void DefaultSceneTransition::setTransition()
 	t = std::thread(setTransitionDelayed, transition, delay);
 	t.detach();
 }
+
+} // namespace advss
