@@ -1,11 +1,12 @@
 #include "macro-action-file.hpp"
-#include "advanced-scene-switcher.hpp"
 #include "utility.hpp"
 
 #include <QFile>
 #include <QTextStream>
 #include <QFileDialog>
 
+namespace advss {
+
 const std::string MacroActionFile::id = "file";
 
 bool MacroActionFile::_registered = MacroActionFactory::Register(
@@ -55,7 +56,7 @@ void MacroActionFile::LogAction() const
 bool MacroActionFile::Save(obs_data_t *obj) const
 {
 	MacroAction::Save(obj);
-	obs_data_set_string(obj, "file", _file.c_str());
+	_file.Save(obj, "file");
 	_text.Save(obj, "text");
 	obs_data_set_int(obj, "action", static_cast<int>(_action));
 	return true;
@@ -64,7 +65,7 @@ bool MacroActionFile::Save(obs_data_t *obj) const
 bool MacroActionFile::Load(obs_data_t *obj)
 {
 	MacroAction::Load(obj);
-	_file = obs_data_get_string(obj, "file");
+	_file.Load(obj, "file");
 	_text.Load(obj, "text");
 	_action = static_cast<FileAction>(obs_data_get_int(obj, "action"));
 	return true;
@@ -72,7 +73,7 @@ bool MacroActionFile::Load(obs_data_t *obj)
 
 std::string MacroActionFile::GetShortDesc() const
 {
-	return _file;
+	return _file.UnresolvedValue();
 }
 
 static inline void populateActionSelection(QComboBox *list)
@@ -106,7 +107,7 @@ MacroActionFileEdit::MacroActionFileEdit(
 		{"{{matchText}}", _text},
 		{"{{actions}}", _actions},
 	};
-	placeWidgets(obs_module_text("AdvSceneSwitcher.action.file.entry"),
+	PlaceWidgets(obs_module_text("AdvSceneSwitcher.action.file.entry"),
 		     entryLayout, widgetPlaceholders);
 
 	QVBoxLayout *mainLayout = new QVBoxLayout;
@@ -139,7 +140,7 @@ void MacroActionFileEdit::PathChanged(const QString &text)
 		return;
 	}
 
-	std::lock_guard<std::mutex> lock(switcher->m);
+	auto lock = LockContext();
 	_entryData->_file = text.toUtf8().constData();
 	emit HeaderInfoChanged(
 		QString::fromStdString(_entryData->GetShortDesc()));
@@ -151,7 +152,7 @@ void MacroActionFileEdit::TextChanged()
 		return;
 	}
 
-	std::lock_guard<std::mutex> lock(switcher->m);
+	auto lock = LockContext();
 	_entryData->_text = _text->toPlainText().toStdString();
 
 	adjustSize();
@@ -164,6 +165,8 @@ void MacroActionFileEdit::ActionChanged(int value)
 		return;
 	}
 
-	std::lock_guard<std::mutex> lock(switcher->m);
+	auto lock = LockContext();
 	_entryData->_action = static_cast<FileAction>(value);
 }
+
+} // namespace advss
