@@ -1,10 +1,15 @@
 #pragma once
 #include "macro-action-edit.hpp"
 #include "variable-text-edit.hpp"
+#include "variable-line-edit.hpp"
 #include "duration-control.hpp"
+#include "string-list.hpp"
 
 #include <QLineEdit>
 #include <QComboBox>
+#include <QCheckBox>
+
+namespace advss {
 
 class MacroActionHttp : public MacroAction {
 public:
@@ -25,13 +30,15 @@ public:
 		POST,
 	};
 
-	std::string _url = obs_module_text("AdvSceneSwitcher.enterURL");
-	VariableResolvingString _data =
-		obs_module_text("AdvSceneSwitcher.enterText");
+	StringVariable _url = obs_module_text("AdvSceneSwitcher.enterURL");
+	StringVariable _data = obs_module_text("AdvSceneSwitcher.enterText");
+	bool _setHeaders = false;
+	StringList _headers;
 	Method _method = Method::GET;
-	Duration _timeout;
+	Duration _timeout = Duration(1.0);
 
 private:
+	void SetupHeaders();
 	void Get();
 	void Post();
 
@@ -59,7 +66,9 @@ private slots:
 	void DataChanged();
 	void URLChanged();
 	void MethodChanged(int);
-	void TimeoutChanged(double seconds);
+	void TimeoutChanged(const Duration &seconds);
+	void SetHeadersChanged(int);
+	void HeadersChanged(const StringList &);
 signals:
 	void HeaderInfoChanged(const QString &);
 
@@ -69,9 +78,14 @@ protected:
 private:
 	void SetWidgetVisibility();
 
-	QLineEdit *_url;
+	VariableLineEdit *_url;
 	QComboBox *_methods;
 	VariableTextEdit *_data;
+	QCheckBox *_setHeaders;
+	QVBoxLayout *_headerListLayout;
+	StringListEdit *_headerList;
 	DurationSelection *_timeout;
 	bool _loading = true;
 };
+
+} // namespace advss
