@@ -1,7 +1,8 @@
 #include "macro-action-media.hpp"
-#include "advanced-scene-switcher.hpp"
 #include "utility.hpp"
 
+namespace advss {
+
 const std::string MacroActionMedia::id = "media";
 
 bool MacroActionMedia::_registered = MacroActionFactory::Register(
@@ -48,7 +49,7 @@ bool MacroActionMedia::PerformAction()
 		obs_source_media_previous(source);
 		break;
 	case MediaAction::SEEK:
-		obs_source_media_set_time(source, _seek.seconds * 1000);
+		obs_source_media_set_time(source, _seek.Milliseconds());
 		break;
 	default:
 		break;
@@ -116,10 +117,8 @@ MacroActionMediaEdit::MacroActionMediaEdit(
 	QWidget::connect(_sources,
 			 SIGNAL(SourceChanged(const SourceSelection &)), this,
 			 SLOT(SourceChanged(const SourceSelection &)));
-	QWidget::connect(_seek, SIGNAL(DurationChanged(double)), this,
-			 SLOT(DurationChanged(double)));
-	QWidget::connect(_seek, SIGNAL(UnitChanged(DurationUnit)), this,
-			 SLOT(DurationUnitChanged(DurationUnit)));
+	QWidget::connect(_seek, SIGNAL(DurationChanged(const Duration &)), this,
+			 SLOT(DurationChanged(const Duration &)));
 
 	QHBoxLayout *mainLayout = new QHBoxLayout;
 	std::unordered_map<std::string, QWidget *> widgetPlaceholders = {
@@ -127,7 +126,7 @@ MacroActionMediaEdit::MacroActionMediaEdit(
 		{"{{actions}}", _actions},
 		{"{{duration}}", _seek},
 	};
-	placeWidgets(obs_module_text("AdvSceneSwitcher.action.media.entry"),
+	PlaceWidgets(obs_module_text("AdvSceneSwitcher.action.media.entry"),
 		     mainLayout, widgetPlaceholders);
 	setLayout(mainLayout);
 
@@ -154,7 +153,7 @@ void MacroActionMediaEdit::SourceChanged(const SourceSelection &source)
 		return;
 	}
 
-	std::lock_guard<std::mutex> lock(switcher->m);
+	auto lock = LockContext();
 	_entryData->_mediaSource = source;
 	emit HeaderInfoChanged(
 		QString::fromStdString(_entryData->GetShortDesc()));
@@ -166,29 +165,19 @@ void MacroActionMediaEdit::ActionChanged(int value)
 		return;
 	}
 
-	std::lock_guard<std::mutex> lock(switcher->m);
+	auto lock = LockContext();
 	_entryData->_action = static_cast<MediaAction>(value);
 	SetWidgetVisibility();
 }
 
-void MacroActionMediaEdit::DurationChanged(double seconds)
+void MacroActionMediaEdit::DurationChanged(const Duration &dur)
 {
 	if (_loading || !_entryData) {
 		return;
 	}
 
-	std::lock_guard<std::mutex> lock(switcher->m);
-	_entryData->_seek.seconds = seconds;
-}
-
-void MacroActionMediaEdit::DurationUnitChanged(DurationUnit unit)
-{
-	if (_loading || !_entryData) {
-		return;
-	}
-
-	std::lock_guard<std::mutex> lock(switcher->m);
-	_entryData->_seek.displayUnit = unit;
+	auto lock = LockContext();
+	_entryData->_seek = dur;
 }
 
 void MacroActionMediaEdit::SetWidgetVisibility()
@@ -199,3 +188,5 @@ void MacroActionMediaEdit::SetWidgetVisibility()
 	_seek->setVisible(_entryData->_action == MediaAction::SEEK);
 	adjustSize();
 }
+
+} // namespace advss
