@@ -1,15 +1,20 @@
 #include "macro-action-plugin-state.hpp"
-#include "advanced-scene-switcher.hpp"
+#include "switcher-data.hpp"
 #include "utility.hpp"
 
 #include <thread>
+#include <QMainWindow>
+
+using namespace std::chrono_literals;
+
+namespace advss {
 
 const std::string MacroActionPluginState::id = "plugin_state";
 
 bool MacroActionPluginState::_registered = MacroActionFactory::Register(
 	MacroActionPluginState::id,
 	{MacroActionPluginState::Create, MacroActionPluginStateEdit::Create,
-	 "AdvSceneSwitcher.action.PluginState"});
+	 "AdvSceneSwitcher.action.pluginState"});
 
 const static std::map<PluginStateAction, std::string> actionTypes = {
 	{PluginStateAction::STOP,
@@ -18,24 +23,26 @@ const static std::map<PluginStateAction, std::string> actionTypes = {
 	 "AdvSceneSwitcher.action.pluginState.type.noMatch"},
 	{PluginStateAction::IMPORT_SETTINGS,
 	 "AdvSceneSwitcher.action.pluginState.type.import"},
+	{PluginStateAction::TERMINATE,
+	 "AdvSceneSwitcher.action.pluginState.type.terminate"},
 };
 
-const static std::map<NoMatch, std::string> noMatchValues = {
-	{NO_SWITCH,
+const static std::map<SwitcherData::NoMatch, std::string> noMatchValues = {
+	{SwitcherData::NoMatch::NO_SWITCH,
 	 "AdvSceneSwitcher.generalTab.generalBehavior.onNoMet.dontSwitch"},
-	{SWITCH,
+	{SwitcherData::NoMatch::SWITCH,
 	 "AdvSceneSwitcher.generalTab.generalBehavior.onNoMet.switchTo"},
-	{RANDOM_SWITCH,
+	{SwitcherData::NoMatch::RANDOM_SWITCH,
 	 "AdvSceneSwitcher.generalTab.generalBehavior.onNoMet.switchToRandom"},
 };
 
-void stopPlugin()
+static void stopPlugin()
 {
 	std::thread t([]() { switcher->Stop(); });
 	t.detach();
 }
 
-void importSettings(const std::string &path)
+static void importSettings(const std::string &path)
 {
 	if (switcher->settingsWindowOpened) {
 		return;
@@ -44,18 +51,91 @@ void importSettings(const std::string &path)
 	if (!obj) {
 		return;
 	}
-	switcher->loadSettings(obj);
+	switcher->LoadSettings(obj);
 	obs_data_release(obj);
 }
 
-void setNoMatchBehaviour(int value, OBSWeakSource &scene)
+static void setNoMatchBehaviour(int value, OBSWeakSource &scene)
 {
-	switcher->switchIfNotMatching = static_cast<NoMatch>(value);
-	if (switcher->switchIfNotMatching == SWITCH) {
+	switcher->switchIfNotMatching =
+		static_cast<SwitcherData::NoMatch>(value);
+	if (switcher->switchIfNotMatching == SwitcherData::NoMatch::SWITCH) {
 		switcher->nonMatchingScene = scene;
 	}
 }
 
+static void closeOBSWindow()
+{
+	blog(LOG_WARNING, "closing OBS window now!");
+	auto obsWindow =
+		static_cast<QMainWindow *>(obs_frontend_get_main_window());
+	if (obsWindow) {
+		obsWindow->close();
+	} else {
+		blog(LOG_WARNING,
+		     "OBS shutdown was aborted - failed to get QMainWindow");
+	}
+}
+
+static void terminateOBS(void *)
+{
+	static std::mutex mtx;
+	static std::mutex waitMutex;
+	static std::condition_variable cv;
+	static bool abortTerminate;
+	static bool stopWaiting;
+	static std::chrono::high_resolution_clock::time_point
+		lastShutdownAttempt{};
+
+	// Don't allow multiple simultaneous instances of the shutdown dialog
+	std::unique_lock<std::mutex> lock(mtx, std::try_to_lock);
+	if (!lock.owns_lock()) {
+		blog(LOG_INFO,
+		     "OBS shutdown dialog already triggered - ignoring additional request");
+		return;
+	}
+
+	// Prevent the user from locking himself out of controlling OBS by
+	// continuously opening the shutdown dialog
+	auto now = std::chrono::high_resolution_clock::now();
+	if (lastShutdownAttempt + 5s > now) {
+		blog(LOG_INFO,
+		     "OBS shutdown dialog already triggered recently - ignoring request");
+		return;
+	}
+	lastShutdownAttempt = now;
+
+	abortTerminate = false;
+	stopWaiting = false;
+
+	// Give the user a 10s grace period during which the shutdown can be aborted
+	std::thread thread([]() {
+		std::unique_lock<std::mutex> lock(waitMutex);
+		if (cv.wait_for(lock, 10s, [] { return stopWaiting; })) {
+			if (abortTerminate) {
+				blog(LOG_INFO, "OBS shutdown was aborted");
+			} else {
+				closeOBSWindow();
+			}
+		} else {
+			closeOBSWindow();
+		}
+	});
+	thread.detach();
+
+	// Ask the user how to proceed
+	abortTerminate = !DisplayMessage(
+		obs_module_text(
+			"AdvSceneSwitcher.action.pluginState.terminateConfirm"),
+		true, false);
+	stopWaiting = true;
+
+	// This closes OBS immediately if shutdown was confirmed
+	cv.notify_all();
+
+	lock.unlock();
+}
+
 bool MacroActionPluginState::PerformAction()
 {
 	switch (_action) {
@@ -70,6 +150,14 @@ bool MacroActionPluginState::PerformAction()
 		// There is no point in continuing
 		// The settings will be invalid
 		return false;
+	case PluginStateAction::TERMINATE: {
+		std::thread thread([]() {
+			obs_queue_task(OBS_TASK_UI, terminateOBS, nullptr,
+				       false);
+		});
+		thread.detach();
+		break;
+	}
 	default:
 		break;
 	}
@@ -89,6 +177,9 @@ void MacroActionPluginState::LogAction() const
 		vblog(LOG_INFO, "importing settings from %s",
 		      _settingsPath.c_str());
 		break;
+	case PluginStateAction::TERMINATE:
+		vblog(LOG_INFO, "sending terminate signal to OBS in 10s");
+		break;
 	default:
 		blog(LOG_WARNING, "ignored unknown pluginState action %d",
 		     static_cast<int>(_action));
@@ -102,7 +193,7 @@ bool MacroActionPluginState::Save(obs_data_t *obj) const
 	obs_data_set_int(obj, "action", static_cast<int>(_action));
 	obs_data_set_int(obj, "value", _value);
 	obs_data_set_string(obj, "scene", GetWeakSourceName(_scene).c_str());
-	obs_data_set_string(obj, "settingsPath", _settingsPath.c_str());
+	_settingsPath.Save(obj, "settingsPath");
 	return true;
 }
 
@@ -114,7 +205,7 @@ bool MacroActionPluginState::Load(obs_data_t *obj)
 	_value = obs_data_get_int(obj, "value");
 	const char *sceneName = obs_data_get_string(obj, "scene");
 	_scene = GetWeakSourceByName(sceneName);
-	_settingsPath = obs_data_get_string(obj, "settingsPath");
+	_settingsPath.Load(obj, "settingsPath");
 	return true;
 }
 
@@ -147,7 +238,7 @@ MacroActionPluginStateEdit::MacroActionPluginStateEdit(
 		"AdvSceneSwitcher.action.pluginState.importWarning"));
 
 	populateActionSelection(_actions);
-	populateSceneSelection(_scenes);
+	PopulateSceneSelection(_scenes);
 
 	QWidget::connect(_actions, SIGNAL(currentIndexChanged(int)), this,
 			 SLOT(ActionChanged(int)));
@@ -166,7 +257,7 @@ MacroActionPluginStateEdit::MacroActionPluginStateEdit(
 		{"{{settings}}", _settings},
 		{"{{settingsWarning}}", _settingsWarning},
 	};
-	placeWidgets(
+	PlaceWidgets(
 		obs_module_text("AdvSceneSwitcher.action.pluginState.entry"),
 		mainLayout, widgetPlaceholders);
 	setLayout(mainLayout);
@@ -185,7 +276,7 @@ void MacroActionPluginStateEdit::UpdateEntryData()
 	populateValueSelection(_values, _entryData->_action);
 	_values->setCurrentIndex(_entryData->_value);
 	_scenes->setCurrentText(GetWeakSourceName(_entryData->_scene).c_str());
-	_settings->SetPath(QString::fromStdString(_entryData->_settingsPath));
+	_settings->SetPath(_entryData->_settingsPath);
 	SetWidgetVisibility();
 }
 
@@ -196,7 +287,7 @@ void MacroActionPluginStateEdit::ActionChanged(int value)
 	}
 
 	{
-		std::lock_guard<std::mutex> lock(switcher->m);
+		auto lock = LockContext();
 		_entryData->_action = static_cast<PluginStateAction>(value);
 		SetWidgetVisibility();
 	}
@@ -211,7 +302,7 @@ void MacroActionPluginStateEdit::ValueChanged(int value)
 		return;
 	}
 
-	std::lock_guard<std::mutex> lock(switcher->m);
+	auto lock = LockContext();
 	_entryData->_value = value;
 	SetWidgetVisibility();
 }
@@ -222,7 +313,7 @@ void MacroActionPluginStateEdit::SceneChanged(const QString &text)
 		return;
 	}
 
-	std::lock_guard<std::mutex> lock(switcher->m);
+	auto lock = LockContext();
 	_entryData->_scene = GetWeakSourceByQString(text);
 }
 
@@ -232,7 +323,7 @@ void MacroActionPluginStateEdit::PathChanged(const QString &text)
 		return;
 	}
 
-	std::lock_guard<std::mutex> lock(switcher->m);
+	auto lock = LockContext();
 	_entryData->_settingsPath = text.toStdString();
 }
 
@@ -251,7 +342,8 @@ void MacroActionPluginStateEdit::SetWidgetVisibility()
 		break;
 	case PluginStateAction::NO_MATCH_BEHAVIOUR:
 		_values->show();
-		if ((NoMatch)_entryData->_value == SWITCH) {
+		if (static_cast<SwitcherData::NoMatch>(_entryData->_value) ==
+		    SwitcherData::NoMatch::SWITCH) {
 			_scenes->show();
 		}
 		break;
@@ -263,3 +355,5 @@ void MacroActionPluginStateEdit::SetWidgetVisibility()
 		break;
 	}
 }
+
+} // namespace advss
