@@ -1,7 +1,8 @@
 #include "macro-action-profile.hpp"
-#include "advanced-scene-switcher.hpp"
 #include "utility.hpp"
 
+namespace advss {
+
 const std::string MacroActionProfile::id = "profile";
 
 bool MacroActionProfile::_registered = MacroActionFactory::Register(
@@ -44,7 +45,7 @@ MacroActionProfileEdit::MacroActionProfileEdit(
 	: QWidget(parent)
 {
 	_profiles = new QComboBox();
-	populateProfileSelection(_profiles);
+	PopulateProfileSelection(_profiles);
 	QWidget::connect(_profiles, SIGNAL(currentTextChanged(const QString &)),
 			 this, SLOT(ProfileChanged(const QString &)));
 
@@ -52,7 +53,7 @@ MacroActionProfileEdit::MacroActionProfileEdit(
 	std::unordered_map<std::string, QWidget *> widgetPlaceholders = {
 		{"{{profiles}}", _profiles},
 	};
-	placeWidgets(obs_module_text("AdvSceneSwitcher.action.profile.entry"),
+	PlaceWidgets(obs_module_text("AdvSceneSwitcher.action.profile.entry"),
 		     mainLayout, widgetPlaceholders);
 	setLayout(mainLayout);
 
@@ -76,8 +77,10 @@ void MacroActionProfileEdit::ProfileChanged(const QString &text)
 		return;
 	}
 
-	std::lock_guard<std::mutex> lock(switcher->m);
+	auto lock = LockContext();
 	_entryData->_profile = text.toStdString();
 	emit HeaderInfoChanged(
 		QString::fromStdString(_entryData->GetShortDesc()));
 }
+
+} // namespace advss
