@@ -1,9 +1,11 @@
 #include "macro-action-random.hpp"
-#include "advanced-scene-switcher.hpp"
+#include "macro.hpp"
 #include "utility.hpp"
 
 #include <cstdlib>
 
+namespace advss {
+
 const std::string MacroActionRandom::id = "random";
 
 bool MacroActionRandom::_registered = MacroActionFactory::Register(
@@ -11,22 +13,30 @@ bool MacroActionRandom::_registered = MacroActionFactory::Register(
 	{MacroActionRandom::Create, MacroActionRandomEdit::Create,
 	 "AdvSceneSwitcher.action.random"});
 
-std::vector<MacroRef> getNextMacros(std::vector<MacroRef> &macros,
-				    MacroRef &lastRandomMacro, bool allowRepeat)
+static bool validNextMacro(const std::shared_ptr<Macro> &macro)
 {
-	std::vector<MacroRef> res;
+	return macro && !macro->Paused();
+}
+
+static std::vector<std::shared_ptr<Macro>>
+getNextMacros(std::vector<MacroRef> &macros, MacroRef &lastRandomMacroRef,
+	      bool allowRepeat)
+{
+	std::vector<std::shared_ptr<Macro>> res;
 	if (macros.size() == 1) {
-		if (!macros[0].get() || macros[0]->Paused()) {
-			return res;
-		} else {
-			return macros;
+		auto macro = macros[0].GetMacro();
+		if (validNextMacro(macro)) {
+			res.push_back(macro);
 		}
+		return res;
 	}
 
+	auto lastRandomMacro = lastRandomMacroRef.GetMacro();
 	for (auto &m : macros) {
-		if (m.get() && !m->Paused() &&
-		    (allowRepeat || (lastRandomMacro.get() != m.get()))) {
-			res.push_back(m);
+		auto macro = m.GetMacro();
+		if (validNextMacro(macro) &&
+		    (allowRepeat || (lastRandomMacro != macro))) {
+			res.push_back(macro);
 		}
 	}
 	return res;
@@ -42,7 +52,7 @@ bool MacroActionRandom::PerformAction()
 	if (macros.size() == 0) {
 		return true;
 	}
-	if (macros.size() == 1 && macros[0].get()) {
+	if (macros.size() == 1) {
 		lastRandomMacro = macros[0];
 		return macros[0]->PerformActions();
 	}
@@ -92,7 +102,7 @@ MacroActionRandomEdit::MacroActionRandomEdit(
 
 	auto *entryLayout = new QHBoxLayout;
 	std::unordered_map<std::string, QWidget *> widgetPlaceholders = {};
-	placeWidgets(obs_module_text("AdvSceneSwitcher.action.random.entry"),
+	PlaceWidgets(obs_module_text("AdvSceneSwitcher.action.random.entry"),
 		     entryLayout, widgetPlaceholders);
 
 	auto *mainLayout = new QVBoxLayout;
@@ -126,8 +136,7 @@ void MacroActionRandomEdit::MacroRemove(const QString &)
 
 	auto it = _entryData->_macros.begin();
 	while (it != _entryData->_macros.end()) {
-		it->UpdateRef();
-		if (it->get() == nullptr) {
+		if (!it->GetMacro()) {
 			it = _entryData->_macros.erase(it);
 		} else {
 			++it;
@@ -142,7 +151,7 @@ void MacroActionRandomEdit::Add(const std::string &name)
 		return;
 	}
 
-	std::lock_guard<std::mutex> lock(switcher->m);
+	auto lock = LockContext();
 	MacroRef macro(name);
 	_entryData->_macros.push_back(macro);
 	_allowRepeat->setVisible(ShouldShowAllowRepeat());
@@ -155,7 +164,7 @@ void MacroActionRandomEdit::Remove(int idx)
 		return;
 	}
 
-	std::lock_guard<std::mutex> lock(switcher->m);
+	auto lock = LockContext();
 	_entryData->_macros.erase(std::next(_entryData->_macros.begin(), idx));
 	_allowRepeat->setVisible(ShouldShowAllowRepeat());
 	adjustSize();
@@ -168,7 +177,7 @@ void MacroActionRandomEdit::Replace(int idx, const std::string &name)
 	}
 
 	MacroRef macro(name);
-	std::lock_guard<std::mutex> lock(switcher->m);
+	auto lock = LockContext();
 	_entryData->_macros[idx] = macro;
 	adjustSize();
 }
@@ -179,7 +188,7 @@ void MacroActionRandomEdit::AllowRepeatChanged(int value)
 		return;
 	}
 
-	std::lock_guard<std::mutex> lock(switcher->m);
+	auto lock = LockContext();
 	_entryData->_allowRepeat = value;
 }
 
@@ -188,11 +197,13 @@ bool MacroActionRandomEdit::ShouldShowAllowRepeat()
 	if (_entryData->_macros.size() <= 1) {
 		return false;
 	}
-	const auto macro = _entryData->_macros[0];
+	const auto macro = _entryData->_macros[0].GetMacro();
 	for (const auto &m : _entryData->_macros) {
-		if (macro.get() != m.get()) {
+		if (macro != m.GetMacro()) {
 			return true;
 		}
 	}
 	return false;
 }
+
+} // namespace advss
