@@ -1,7 +1,8 @@
 #include "macro-action-replay-buffer.hpp"
-#include "advanced-scene-switcher.hpp"
 #include "utility.hpp"
 
+namespace advss {
+
 const std::string MacroActionReplayBuffer::id = "replay_buffer";
 
 bool MacroActionReplayBuffer::_registered = MacroActionFactory::Register(
@@ -89,7 +90,7 @@ MacroActionReplayBufferEdit::MacroActionReplayBufferEdit(
 	std::unordered_map<std::string, QWidget *> widgetPlaceholders = {
 		{"{{actions}}", _actions},
 	};
-	placeWidgets(obs_module_text("AdvSceneSwitcher.action.replay.entry"),
+	PlaceWidgets(obs_module_text("AdvSceneSwitcher.action.replay.entry"),
 		     layout, widgetPlaceholders);
 	QVBoxLayout *mainLayout = new QVBoxLayout;
 	mainLayout->addLayout(layout);
@@ -117,9 +118,11 @@ void MacroActionReplayBufferEdit::ActionChanged(int value)
 		return;
 	}
 
-	std::lock_guard<std::mutex> lock(switcher->m);
+	auto lock = LockContext();
 	_entryData->_action = static_cast<ReplayBufferAction>(value);
 	_saveWarning->setVisible(_entryData->_action ==
 				 ReplayBufferAction::SAVE);
 	adjustSize();
 }
+
+} // namespace advss
