@@ -1,7 +1,9 @@
 #include "macro-action-scene-collection.hpp"
-#include "advanced-scene-switcher.hpp"
+#include "switcher-data.hpp"
 #include "utility.hpp"
 
+namespace advss {
+
 const std::string MacroActionSceneCollection::id = "scene_collection";
 
 bool MacroActionSceneCollection::_registered = MacroActionFactory::Register(
@@ -60,7 +62,7 @@ void populateSceneCollectionSelection(QComboBox *box)
 	}
 	bfree(sceneCollections);
 	box->model()->sort(0);
-	addSelectionEntry(
+	AddSelectionEntry(
 		box, obs_module_text("AdvSceneSwitcher.selectSceneCollection"),
 		false);
 	box->setCurrentIndex(0);
@@ -80,7 +82,7 @@ MacroActionSceneCollectionEdit::MacroActionSceneCollectionEdit(
 	std::unordered_map<std::string, QWidget *> widgetPlaceholders = {
 		{"{{sceneCollections}}", _sceneCollections},
 	};
-	placeWidgets(obs_module_text(
+	PlaceWidgets(obs_module_text(
 			     "AdvSceneSwitcher.action.sceneCollection.entry"),
 		     entryLayout, widgetPlaceholders);
 	QVBoxLayout *mainLayout = new QVBoxLayout;
@@ -110,8 +112,10 @@ void MacroActionSceneCollectionEdit::SceneCollectionChanged(const QString &text)
 		return;
 	}
 
-	std::lock_guard<std::mutex> lock(switcher->m);
+	auto lock = LockContext();
 	_entryData->_sceneCollection = text.toStdString();
 	emit HeaderInfoChanged(
 		QString::fromStdString(_entryData->GetShortDesc()));
 }
+
+} // namespace advss
