@@ -1,7 +1,8 @@
 #include "macro-action-screenshot.hpp"
-#include "advanced-scene-switcher.hpp"
 #include "utility.hpp"
 
+namespace advss {
+
 const uint32_t MacroActionScreenshot::_version = 1;
 
 const std::string MacroActionScreenshot::id = "screenshot";
@@ -87,7 +88,7 @@ bool MacroActionScreenshot::Save(obs_data_t *obj) const
 	_source.Save(obj);
 	obs_data_set_int(obj, "saveType", static_cast<int>(_saveType));
 	obs_data_set_int(obj, "targetType", static_cast<int>(_targetType));
-	obs_data_set_string(obj, "savePath", _path.c_str());
+	_path.Save(obj, "savePath");
 	obs_data_set_int(obj, "version", _version);
 	return true;
 }
@@ -100,7 +101,7 @@ bool MacroActionScreenshot::Load(obs_data_t *obj)
 	_saveType = static_cast<SaveType>(obs_data_get_int(obj, "saveType"));
 	_targetType =
 		static_cast<TargetType>(obs_data_get_int(obj, "targetType"));
-	_path = obs_data_get_string(obj, "savePath");
+	_path.Load(obj, "savePath");
 
 	// TODO: Remove fallback for older versions
 	if (!obs_data_has_user_value(obj, "version")) {
@@ -176,7 +177,7 @@ MacroActionScreenshotEdit::MacroActionScreenshotEdit(
 		{"{{saveType}}", _saveType},
 		{"{{targetType}}", _targetType},
 	};
-	placeWidgets(
+	PlaceWidgets(
 		obs_module_text("AdvSceneSwitcher.action.screenshot.entry"),
 		layout, widgetPlaceholders);
 
@@ -200,7 +201,7 @@ void MacroActionScreenshotEdit::UpdateEntryData()
 	_scenes->SetScene(_entryData->_scene);
 	_saveType->setCurrentIndex(static_cast<int>(_entryData->_saveType));
 	_targetType->setCurrentIndex(static_cast<int>(_entryData->_targetType));
-	_savePath->SetPath(QString::fromStdString(_entryData->_path));
+	_savePath->SetPath(_entryData->_path);
 	SetWidgetVisibility();
 }
 
@@ -210,7 +211,7 @@ void MacroActionScreenshotEdit::SceneChanged(const SceneSelection &s)
 		return;
 	}
 
-	std::lock_guard<std::mutex> lock(switcher->m);
+	auto lock = LockContext();
 	_entryData->_scene = s;
 	emit HeaderInfoChanged(
 		QString::fromStdString(_entryData->GetShortDesc()));
@@ -242,8 +243,8 @@ void MacroActionScreenshotEdit::PathChanged(const QString &text)
 		return;
 	}
 
-	std::lock_guard<std::mutex> lock(switcher->m);
-	_entryData->_path = text.toUtf8().constData();
+	auto lock = LockContext();
+	_entryData->_path = text.toStdString();
 }
 
 void MacroActionScreenshotEdit::SourceChanged(const SourceSelection &source)
@@ -252,7 +253,7 @@ void MacroActionScreenshotEdit::SourceChanged(const SourceSelection &source)
 		return;
 	}
 
-	std::lock_guard<std::mutex> lock(switcher->m);
+	auto lock = LockContext();
 	_entryData->_source = source;
 	emit HeaderInfoChanged(
 		QString::fromStdString(_entryData->GetShortDesc()));
@@ -272,3 +273,5 @@ void MacroActionScreenshotEdit::SetWidgetVisibility()
 
 	adjustSize();
 }
+
+} // namespace advss
