@@ -7,6 +7,8 @@
 
 #include <QComboBox>
 
+namespace advss {
+
 class MacroActionScreenshot : public MacroAction {
 public:
 	MacroActionScreenshot(Macro *m) : MacroAction(m) {}
@@ -33,7 +35,7 @@ public:
 	TargetType _targetType = TargetType::SOURCE;
 	SceneSelection _scene;
 	SourceSelection _source;
-	std::string _path = obs_module_text("AdvSceneSwitcher.enterPath");
+	StringVariable _path = obs_module_text("AdvSceneSwitcher.enterPath");
 
 private:
 	void FrontendScreenshot(OBSWeakSource &);
@@ -84,3 +86,5 @@ private:
 
 	bool _loading = true;
 };
+
+} // namespace advss
