@@ -1,7 +1,9 @@
 #include "macro-action-sequence.hpp"
-#include "advanced-scene-switcher.hpp"
+#include "macro.hpp"
 #include "utility.hpp"
 
+namespace advss {
+
 const std::string MacroActionSequence::id = "sequence";
 
 bool MacroActionSequence::_registered = MacroActionFactory::Register(
@@ -9,10 +11,11 @@ bool MacroActionSequence::_registered = MacroActionFactory::Register(
 	{MacroActionSequence::Create, MacroActionSequenceEdit::Create,
 	 "AdvSceneSwitcher.action.sequence"});
 
-int getNextUnpausedMacroIdx(std::vector<MacroRef> &macros, int startIdx)
+static int getNextUnpausedMacroIdx(std::vector<MacroRef> &macros, int startIdx)
 {
 	for (; (int)macros.size() > startIdx; ++startIdx) {
-		if (macros[startIdx].get() && !macros[startIdx]->Paused()) {
+		auto macro = macros[startIdx].GetMacro();
+		if (macro && !macro->Paused()) {
 			return startIdx;
 		}
 	}
@@ -58,7 +61,7 @@ bool MacroActionSequence::PerformAction()
 		return true;
 	}
 
-	auto macro = GetNextMacro();
+	auto macro = GetNextMacro().GetMacro();
 	if (!macro.get()) {
 		return true;
 	}
@@ -119,7 +122,7 @@ MacroActionSequenceEdit::MacroActionSequenceEdit(
 
 	auto *entryLayout = new QHBoxLayout;
 	std::unordered_map<std::string, QWidget *> widgetPlaceholders = {};
-	placeWidgets(obs_module_text("AdvSceneSwitcher.action.sequence.entry"),
+	PlaceWidgets(obs_module_text("AdvSceneSwitcher.action.sequence.entry"),
 		     entryLayout, widgetPlaceholders);
 
 	auto *mainLayout = new QVBoxLayout;
@@ -158,8 +161,8 @@ void MacroActionSequenceEdit::MacroRemove(const QString &)
 
 	auto it = _entryData->_macros.begin();
 	while (it != _entryData->_macros.end()) {
-		it->UpdateRef();
-		if (it->get() == nullptr) {
+
+		if (!it->GetMacro()) {
 			it = _entryData->_macros.erase(it);
 		} else {
 			++it;
@@ -174,7 +177,7 @@ void MacroActionSequenceEdit::Add(const std::string &name)
 		return;
 	}
 
-	std::lock_guard<std::mutex> lock(switcher->m);
+	auto lock = LockContext();
 	MacroRef macro(name);
 	_entryData->_macros.push_back(macro);
 	adjustSize();
@@ -186,7 +189,7 @@ void MacroActionSequenceEdit::Remove(int idx)
 		return;
 	}
 
-	std::lock_guard<std::mutex> lock(switcher->m);
+	auto lock = LockContext();
 	_entryData->_macros.erase(std::next(_entryData->_macros.begin(), idx));
 	adjustSize();
 }
@@ -197,13 +200,13 @@ void MacroActionSequenceEdit::Up(int idx)
 		return;
 	}
 
-	std::lock_guard<std::mutex> lock(switcher->m);
+	auto lock = LockContext();
 	std::swap(_entryData->_macros[idx], _entryData->_macros[idx - 1]);
 }
 
 void MacroActionSequenceEdit::Down(int idx)
 {
-	std::lock_guard<std::mutex> lock(switcher->m);
+	auto lock = LockContext();
 	std::swap(_entryData->_macros[idx], _entryData->_macros[idx + 1]);
 }
 
@@ -214,7 +217,7 @@ void MacroActionSequenceEdit::Replace(int idx, const std::string &name)
 	}
 
 	MacroRef macro(name);
-	std::lock_guard<std::mutex> lock(switcher->m);
+	auto lock = LockContext();
 	_entryData->_macros[idx] = macro;
 	adjustSize();
 }
@@ -229,7 +232,7 @@ void MacroActionSequenceEdit::ContinueFromClicked()
 	if (idx == -1) {
 		return;
 	}
-	std::lock_guard<std::mutex> lock(switcher->m);
+	auto lock = LockContext();
 	_entryData->_lastIdx = idx - 1;
 }
 
@@ -239,7 +242,7 @@ void MacroActionSequenceEdit::RestartChanged(int state)
 		return;
 	}
 
-	std::lock_guard<std::mutex> lock(switcher->m);
+	auto lock = LockContext();
 	_entryData->_restart = state;
 }
 
@@ -250,12 +253,11 @@ void MacroActionSequenceEdit::UpdateStatusLine()
 	QString nextMacroName =
 		obs_module_text("AdvSceneSwitcher.action.sequence.status.none");
 	if (_entryData) {
-		if (_entryData->_lastSequenceMacro.get()) {
-			lastMacroName = QString::fromStdString(
-				_entryData->_lastSequenceMacro->Name());
+		if (auto macro = _entryData->_lastSequenceMacro.GetMacro()) {
+			lastMacroName = QString::fromStdString(macro->Name());
 		}
-		auto next = _entryData->GetNextMacro(false);
-		if (next.get()) {
+		auto next = _entryData->GetNextMacro(false).GetMacro();
+		if (next) {
 			nextMacroName = QString::fromStdString(next->Name());
 		}
 	}
@@ -264,3 +266,5 @@ void MacroActionSequenceEdit::UpdateStatusLine()
 		obs_module_text("AdvSceneSwitcher.action.sequence.status")};
 	_statusLine->setText(format.arg(lastMacroName, nextMacroName));
 }
+
+} // namespace advss
