@@ -1,7 +1,8 @@
 #include "macro-action-studio-mode.hpp"
-#include "advanced-scene-switcher.hpp"
 #include "utility.hpp"
 
+namespace advss {
+
 const std::string MacroActionSudioMode::id = "studio_mode";
 
 bool MacroActionSudioMode::_registered = MacroActionFactory::Register(
@@ -9,16 +10,6 @@ bool MacroActionSudioMode::_registered = MacroActionFactory::Register(
 	{MacroActionSudioMode::Create, MacroActionSudioModeEdit::Create,
 	 "AdvSceneSwitcher.action.studioMode"});
 
-// TODO: Remove in future version (backwards compatibility)
-static const std::string idOld1 = "scene_swap";
-static const std::string idOld2 = "preview_scene";
-static bool oldRegisterd1 = MacroActionFactory::Register(
-	idOld1, {MacroActionSudioMode::Create, MacroActionSudioModeEdit::Create,
-		 "AdvSceneSwitcher.action.studioMode"});
-static bool oldRegisterd2 = MacroActionFactory::Register(
-	idOld2, {MacroActionSudioMode::Create, MacroActionSudioModeEdit::Create,
-		 "AdvSceneSwitcher.action.studioMode"});
-
 const static std::map<StudioModeAction, std::string> actionTypes = {
 	{StudioModeAction::SWAP_SCENE,
 	 "AdvSceneSwitcher.action.studioMode.type.swap"},
@@ -98,10 +89,6 @@ bool MacroActionSudioMode::Load(obs_data_t *obj)
 	_action =
 		static_cast<StudioModeAction>(obs_data_get_int(obj, "action"));
 	_scene.Load(obj);
-	// TODO: Remove in future version (backwards compatibility)
-	if (obs_data_get_string(obj, "id") == idOld2) {
-		_action = StudioModeAction::SET_SCENE;
-	}
 	return true;
 }
 
@@ -137,7 +124,7 @@ MacroActionSudioModeEdit::MacroActionSudioModeEdit(
 		{"{{scenes}}", _scenes},
 	};
 	QHBoxLayout *mainLayout = new QHBoxLayout;
-	placeWidgets(
+	PlaceWidgets(
 		obs_module_text("AdvSceneSwitcher.action.studioMode.entry"),
 		mainLayout, widgetPlaceholders);
 	setLayout(mainLayout);
@@ -163,7 +150,7 @@ void MacroActionSudioModeEdit::SceneChanged(const SceneSelection &s)
 		return;
 	}
 
-	std::lock_guard<std::mutex> lock(switcher->m);
+	auto lock = LockContext();
 	_entryData->_scene = s;
 	emit HeaderInfoChanged(
 		QString::fromStdString(_entryData->GetShortDesc()));
@@ -175,9 +162,11 @@ void MacroActionSudioModeEdit::ActionChanged(int value)
 		return;
 	}
 
-	std::lock_guard<std::mutex> lock(switcher->m);
+	auto lock = LockContext();
 	_entryData->_action = static_cast<StudioModeAction>(value);
 	_scenes->setVisible(_entryData->_action == StudioModeAction::SET_SCENE);
 	emit HeaderInfoChanged(
 		QString::fromStdString(_entryData->GetShortDesc()));
 }
+
+} // namespace advss
