@@ -1,8 +1,12 @@
 #pragma once
 #include "macro-action-edit.hpp"
+#include "variable-string.hpp"
+#include "file-selection.hpp"
 
 #include <QLineEdit>
 
+namespace advss {
+
 class MacroActionSystray : public MacroAction {
 public:
 	MacroActionSystray(Macro *m) : MacroAction(m) {}
@@ -16,9 +20,14 @@ public:
 		return std::make_shared<MacroActionSystray>(m);
 	}
 
-	std::string _msg = "";
+	StringVariable _message = "";
+	StringVariable _title = obs_module_text("AdvSceneSwitcher.pluginName");
+	StringVariable _iconPath = "";
 
 private:
+	QIcon _icon;
+	std::string _lastPath;
+
 	static bool _registered;
 	static const std::string id;
 };
@@ -40,11 +49,17 @@ public:
 
 private slots:
 	void MessageChanged();
+	void TitleChanged();
+	void IconPathChanged(const QString &text);
 
 protected:
 	std::shared_ptr<MacroActionSystray> _entryData;
 
 private:
-	QLineEdit *_msg;
+	VariableLineEdit *_message;
+	VariableLineEdit *_title;
+	FileSelection *_iconPath;
 	bool _loading = true;
 };
+
+} // namespace advss
