@@ -6,6 +6,8 @@
 #include <QDoubleSpinBox>
 #include <QHBoxLayout>
 
+namespace advss {
+
 enum class TimerAction {
 	PAUSE,
 	CONTINUE,
@@ -52,9 +54,7 @@ public:
 
 private slots:
 	void MacroChanged(const QString &text);
-	void MacroRemove(const QString &name);
-	void DurationChanged(double value);
-	void DurationUnitChanged(DurationUnit unit);
+	void DurationChanged(const Duration &value);
 	void ActionTypeChanged(int value);
 signals:
 	void HeaderInfoChanged(const QString &);
@@ -71,3 +71,5 @@ private:
 	QHBoxLayout *_mainLayout;
 	bool _loading = true;
 };
+
+} // namespace advss
