@@ -4,6 +4,7 @@
 #include "advanced-scene-switcher.hpp"
 #include "macro.hpp"
 #include "math-helpers.hpp"
+#include "non-modal-dialog.hpp"
 #include "utility.hpp"
 
 namespace advss {
@@ -15,7 +16,7 @@ bool MacroActionVariable::_registered = MacroActionFactory::Register(
 	{MacroActionVariable::Create, MacroActionVariableEdit::Create,
 	 "AdvSceneSwitcher.action.variable"});
 
-static std::map<MacroActionVariable::Type, std::string> actionTypes = {
+const static std::map<MacroActionVariable::Type, std::string> actionTypes = {
 	{MacroActionVariable::Type::SET_FIXED_VALUE,
 	 "AdvSceneSwitcher.action.variable.type.set"},
 	{MacroActionVariable::Type::APPEND,
@@ -38,6 +39,8 @@ static std::map<MacroActionVariable::Type, std::string> actionTypes = {
 	 "AdvSceneSwitcher.action.variable.type.findAndReplace"},
 	{MacroActionVariable::Type::MATH_EXPRESSION,
 	 "AdvSceneSwitcher.action.variable.type.mathExpression"},
+	{MacroActionVariable::Type::USER_INPUT,
+	 "AdvSceneSwitcher.action.variable.type.askForValue"},
 };
 
 static void apppend(Variable &var, const std::string &value)
@@ -121,6 +124,19 @@ void MacroActionVariable::HandleMathExpression(Variable *var)
 	var->SetValue(std::get<double>(result));
 }
 
+struct AskForInputParams {
+	QString prompt;
+	std::optional<std::string> result;
+};
+
+static void askForInput(void *param)
+{
+	auto parameters = static_cast<AskForInputParams *>(param);
+	auto dialog = new NonModalMessageDialog(
+		parameters->prompt, NonModalMessageDialog::Type::INPUT);
+	parameters->result = dialog->GetInput();
+}
+
 bool MacroActionVariable::PerformAction()
 {
 	auto var = _variable.lock();
@@ -189,6 +205,22 @@ bool MacroActionVariable::PerformAction()
 		HandleMathExpression(var.get());
 		return true;
 	}
+	case Type::USER_INPUT: {
+		AskForInputParams params{
+			_useCustomPrompt
+				? QString::fromStdString(_inputPrompt)
+				: QString(obs_module_text(
+						  "AdvSceneSwitcher.action.variable.askForValuePromptDefault"))
+					  .arg(QString::fromStdString(
+						  var->Name())),
+			{}};
+		obs_queue_task(OBS_TASK_UI, askForInput, &params, true);
+		if (!params.result.has_value()) {
+			return false;
+		}
+		var->SetValue(*params.result);
+		return true;
+	}
 	}
 
 	return true;
@@ -213,6 +245,8 @@ bool MacroActionVariable::Save(obs_data_t *obj) const
 	obs_data_set_string(obj, "replaceStr", _replaceStr.c_str());
 	_regex.Save(obj);
 	_mathExpression.Save(obj, "mathExpression");
+	obs_data_set_bool(obj, "useCustomPrompt", _useCustomPrompt);
+	_inputPrompt.Save(obj, "inputPrompt");
 	return true;
 }
 
@@ -235,6 +269,8 @@ bool MacroActionVariable::Load(obs_data_t *obj)
 	_findStr = obs_data_get_string(obj, "findStr");
 	_replaceStr = obs_data_get_string(obj, "replaceStr");
 	_mathExpression.Load(obj, "mathExpression");
+	_useCustomPrompt = obs_data_get_bool(obj, "useCustomPrompt");
+	_inputPrompt.Load(obj, "inputPrompt");
 	return true;
 }
 
@@ -337,7 +373,8 @@ MacroActionVariableEdit::MacroActionVariableEdit(
 	  _actions(new QComboBox()),
 	  _strValue(new ResizingPlainTextEdit(this, 5, 1, 1)),
 	  _numValue(new QDoubleSpinBox()),
-	  _segmentIdx(new QSpinBox()),
+	  _segmentIdx(new MacroSegmentSelection(
+		  this, MacroSegmentSelection::Type::CONDITION, false)),
 	  _segmentValueStatus(new QLabel()),
 	  _segmentValue(new ResizingPlainTextEdit(this, 10, 1, 1)),
 	  _substringLayout(new QVBoxLayout()),
@@ -352,13 +389,13 @@ MacroActionVariableEdit::MacroActionVariableEdit(
 	  _findStr(new ResizingPlainTextEdit(this, 10, 1, 1)),
 	  _replaceStr(new ResizingPlainTextEdit(this, 10, 1, 1)),
 	  _mathExpression(new VariableLineEdit(this)),
-	  _mathExpressionResult(new QLabel())
+	  _mathExpressionResult(new QLabel()),
+	  _promptLayout(new QHBoxLayout()),
+	  _useCustomPrompt(new QCheckBox()),
+	  _inputPrompt(new VariableLineEdit(this))
 {
 	_numValue->setMinimum(-9999999999);
 	_numValue->setMaximum(9999999999);
-	_segmentIdx->setMinimum(0);
-	_segmentIdx->setMaximum(99);
-	_segmentIdx->setSpecialValueText("-");
 	_segmentValue->setReadOnly(true);
 	_subStringStart->setMinimum(1);
 	_subStringStart->setMaximum(99999);
@@ -371,6 +408,8 @@ MacroActionVariableEdit::MacroActionVariableEdit(
 	_regexMatchIdx->setMinimum(1);
 	_regexMatchIdx->setMaximum(999);
 	_regexMatchIdx->setSuffix(".");
+	_inputPrompt->setSizePolicy(QSizePolicy::MinimumExpanding,
+				    QSizePolicy::Preferred);
 	populateTypeSelection(_actions);
 
 	QWidget::connect(_variables, SIGNAL(SelectionChanged(const QString &)),
@@ -383,8 +422,9 @@ MacroActionVariableEdit::MacroActionVariableEdit(
 			 SLOT(StrValueChanged()));
 	QWidget::connect(_numValue, SIGNAL(valueChanged(double)), this,
 			 SLOT(NumValueChanged(double)));
-	QWidget::connect(_segmentIdx, SIGNAL(valueChanged(int)), this,
-			 SLOT(SegmentIndexChanged(int)));
+	QWidget::connect(_segmentIdx,
+			 SIGNAL(SelectionChanged(const IntVariable &)), this,
+			 SLOT(SegmentIndexChanged(const IntVariable &)));
 	QWidget::connect(window(), SIGNAL(MacroSegmentOrderChanged()), this,
 			 SLOT(MacroSegmentOrderChanged()));
 	QWidget::connect(_subStringStart, SIGNAL(valueChanged(int)), this,
@@ -403,6 +443,10 @@ MacroActionVariableEdit::MacroActionVariableEdit(
 			 SLOT(ReplaceStrValueChanged()));
 	QWidget::connect(_mathExpression, SIGNAL(editingFinished()), this,
 			 SLOT(MathExpressionChanged()));
+	QWidget::connect(_useCustomPrompt, SIGNAL(stateChanged(int)), this,
+			 SLOT(UseCustomPromptChanged(int)));
+	QWidget::connect(_inputPrompt, SIGNAL(editingFinished()), this,
+			 SLOT(InputPromptChanged()));
 
 	std::unordered_map<std::string, QWidget *> widgetPlaceholders = {
 		{"{{variables}}", _variables},
@@ -417,6 +461,8 @@ MacroActionVariableEdit::MacroActionVariableEdit(
 		{"{{findStr}}", _findStr},
 		{"{{replaceStr}}", _replaceStr},
 		{"{{mathExpression}}", _mathExpression},
+		{"{{useCustomPrompt}}", _useCustomPrompt},
+		{"{{inputPrompt}}", _inputPrompt},
 	};
 	auto entryLayout = new QHBoxLayout;
 	PlaceWidgets(obs_module_text("AdvSceneSwitcher.action.variable.entry"),
@@ -437,6 +483,11 @@ MacroActionVariableEdit::MacroActionVariableEdit(
 			"AdvSceneSwitcher.action.variable.entry.findAndReplace"),
 		_findReplaceLayout, widgetPlaceholders, false);
 
+	PlaceWidgets(
+		obs_module_text(
+			"AdvSceneSwitcher.action.variable.entry.userInput"),
+		_promptLayout, widgetPlaceholders);
+
 	auto regexConfigLayout = new QHBoxLayout;
 	regexConfigLayout->addWidget(_regex);
 	regexConfigLayout->addStretch();
@@ -453,6 +504,7 @@ MacroActionVariableEdit::MacroActionVariableEdit(
 	layout->addWidget(_segmentValue);
 	layout->addLayout(_findReplaceLayout);
 	layout->addWidget(_mathExpressionResult);
+	layout->addLayout(_promptLayout);
 	setLayout(layout);
 
 	_entryData = entryData;
@@ -476,7 +528,13 @@ void MacroActionVariableEdit::UpdateEntryData()
 	_actions->setCurrentIndex(static_cast<int>(_entryData->_type));
 	_strValue->setPlainText(QString::fromStdString(_entryData->_strValue));
 	_numValue->setValue(_entryData->_numValue);
-	_segmentIdx->setValue(_entryData->GetSegmentIndexValue() + 1);
+	_segmentIdx->SetValue(_entryData->GetSegmentIndexValue() + 1);
+	_segmentIdx->SetMacro(_entryData->GetMacro());
+	_segmentIdx->SetType(
+		_entryData->_type ==
+				MacroActionVariable::Type::SET_CONDITION_VALUE
+			? MacroSegmentSelection::Type::CONDITION
+			: MacroSegmentSelection::Type::ACTION);
 	_subStringStart->setValue(_entryData->_subStringStart + 1);
 	_subStringSize->setValue(_entryData->_subStringSize);
 	_regex->SetRegexConfig(_entryData->_regex);
@@ -487,6 +545,8 @@ void MacroActionVariableEdit::UpdateEntryData()
 	_replaceStr->setPlainText(
 		QString::fromStdString(_entryData->_replaceStr));
 	_mathExpression->setText(_entryData->_mathExpression);
+	_useCustomPrompt->setChecked(_entryData->_useCustomPrompt);
+	_inputPrompt->setText(_entryData->_inputPrompt);
 	SetWidgetVisibility();
 }
 
@@ -518,13 +578,14 @@ void MacroActionVariableEdit::ActionChanged(int value)
 
 	auto lock = LockContext();
 	_entryData->_type = static_cast<MacroActionVariable::Type>(value);
-	SetWidgetVisibility();
 
-	if (_entryData->_type == MacroActionVariable::Type::SET_ACTION_VALUE ||
-	    _entryData->_type ==
-		    MacroActionVariable::Type::SET_CONDITION_VALUE) {
-		MarkSelectedSegment();
+	if (_entryData->_type == MacroActionVariable::Type::SET_ACTION_VALUE) {
+		_segmentIdx->SetType(MacroSegmentSelection::Type::ACTION);
+	} else if (_entryData->_type ==
+		   MacroActionVariable::Type::SET_CONDITION_VALUE) {
+		_segmentIdx->SetType(MacroSegmentSelection::Type::CONDITION);
 	}
+	SetWidgetVisibility();
 }
 
 void MacroActionVariableEdit::StrValueChanged()
@@ -549,7 +610,7 @@ void MacroActionVariableEdit::NumValueChanged(double val)
 	_entryData->_numValue = val;
 }
 
-void MacroActionVariableEdit::SegmentIndexChanged(int val)
+void MacroActionVariableEdit::SegmentIndexChanged(const IntVariable &val)
 {
 	if (_loading || !_entryData) {
 		return;
@@ -557,7 +618,6 @@ void MacroActionVariableEdit::SegmentIndexChanged(int val)
 
 	auto lock = LockContext();
 	_entryData->SetSegmentIndexValue(val - 1);
-	MarkSelectedSegment();
 }
 
 void MacroActionVariableEdit::SetSegmentValueError(const QString &text)
@@ -590,7 +650,7 @@ void MacroActionVariableEdit::UpdateSegmentVariableValue()
 		SetSegmentValueError(obs_module_text(
 			"AdvSceneSwitcher.action.variable.invalidSelection"));
 		const QSignalBlocker b(_segmentIdx);
-		_segmentIdx->setValue(index);
+		_segmentIdx->SetValue(0);
 		return;
 	}
 
@@ -649,7 +709,7 @@ void MacroActionVariableEdit::UpdateSegmentVariableValue()
 void MacroActionVariableEdit::MacroSegmentOrderChanged()
 {
 	const QSignalBlocker b(_segmentIdx);
-	_segmentIdx->setValue(_entryData->GetSegmentIndexValue() + 1);
+	_segmentIdx->SetValue(_entryData->GetSegmentIndexValue() + 1);
 }
 
 void MacroActionVariableEdit::SubStringStartChanged(int val)
@@ -752,40 +812,31 @@ void MacroActionVariableEdit::MathExpressionChanged()
 	updateGeometry();
 }
 
-void MacroActionVariableEdit::MarkSelectedSegment()
+void MacroActionVariableEdit::UseCustomPromptChanged(int value)
 {
-	if (switcher->disableHints) {
+	if (_loading || !_entryData) {
 		return;
 	}
 
-	auto m = _entryData->GetMacro();
-	if (!m) {
-		return;
-	}
-
-	int index = _entryData->GetSegmentIndexValue();
-	if (index < 0) {
-		return;
-	}
-
-	if (_entryData->_type == MacroActionVariable::Type::SET_ACTION_VALUE) {
-		const auto &actions = m->Actions();
-		if (index >= (int)actions.size()) {
-			return;
-		}
-		AdvSceneSwitcher::window->HighlightAction(
-			index, QColor(Qt::lightGray));
+	_inputPrompt->setVisible(value);
+	if (value) {
+		RemoveStretchIfPresent(_promptLayout);
 	} else {
-		const auto &conditions = m->Conditions();
-		if (index >= (int)conditions.size()) {
-			return;
-		}
-		AdvSceneSwitcher::window->HighlightCondition(
-			index, QColor(Qt::lightGray));
+		AddStretchIfNecessary(_promptLayout);
 	}
 
-	PulseWidget(_segmentIdx, QColor(Qt::lightGray), QColor(0, 0, 0, 0),
-		    true);
+	auto lock = LockContext();
+	_entryData->_useCustomPrompt = value;
+}
+
+void MacroActionVariableEdit::InputPromptChanged()
+{
+	if (_loading || !_entryData) {
+		return;
+	}
+
+	auto lock = LockContext();
+	_entryData->_inputPrompt = _inputPrompt->text().toStdString();
 }
 
 void MacroActionVariableEdit::SetWidgetVisibility()
@@ -833,7 +884,10 @@ void MacroActionVariableEdit::SetWidgetVisibility()
 	_mathExpression->setVisible(_entryData->_type ==
 				    MacroActionVariable::Type::MATH_EXPRESSION);
 	_mathExpressionResult->hide();
-
+	SetLayoutVisible(_promptLayout,
+			 _entryData->_type ==
+				 MacroActionVariable::Type::USER_INPUT);
+	_inputPrompt->setVisible(_entryData->_useCustomPrompt);
 	adjustSize();
 	updateGeometry();
 }
