@@ -1,7 +1,8 @@
 #include "macro-action-virtual-cam.hpp"
-#include "advanced-scene-switcher.hpp"
 #include "utility.hpp"
 
+namespace advss {
+
 const std::string MacroActionVCam::id = "virtual_cam";
 
 bool MacroActionVCam::_registered = MacroActionFactory::Register(
@@ -82,7 +83,7 @@ MacroActionVCamEdit::MacroActionVCamEdit(
 	std::unordered_map<std::string, QWidget *> widgetPlaceholders = {
 		{"{{actions}}", _actions},
 	};
-	placeWidgets(
+	PlaceWidgets(
 		obs_module_text("AdvSceneSwitcher.action.virtualCamera.entry"),
 		mainLayout, widgetPlaceholders);
 	setLayout(mainLayout);
@@ -106,6 +107,8 @@ void MacroActionVCamEdit::ActionChanged(int value)
 		return;
 	}
 
-	std::lock_guard<std::mutex> lock(switcher->m);
+	auto lock = LockContext();
 	_entryData->_action = static_cast<VCamAction>(value);
 }
+
+} // namespace advss
