@@ -5,6 +5,8 @@
 #include <QDoubleSpinBox>
 #include <QHBoxLayout>
 
+namespace advss {
+
 enum class WaitType {
 	FIXED,
 	RANDOM,
@@ -49,10 +51,8 @@ public:
 	}
 
 private slots:
-	void DurationChanged(double value);
-	void DurationUnitChanged(DurationUnit unit);
-	void Duration2Changed(double value);
-	void Duration2UnitChanged(DurationUnit unit);
+	void DurationChanged(const Duration &value);
+	void Duration2Changed(const Duration &value);
 	void TypeChanged(int value);
 
 protected:
@@ -65,3 +65,5 @@ private:
 	QHBoxLayout *_mainLayout;
 	bool _loading = true;
 };
+
+} // namespace advss
