@@ -1,5 +1,5 @@
 #pragma once
-#include "macro.hpp"
+#include "macro-condition-edit.hpp"
 #include "duration-control.hpp"
 
 #include <QCheckBox>
@@ -7,6 +7,8 @@
 #include <QComboBox>
 #include <QTimer>
 
+namespace advss {
+
 class MacroConditionDate : public MacroCondition {
 public:
 	MacroConditionDate(Macro *m) : MacroCondition(m, true) {}
@@ -100,8 +102,7 @@ private slots:
 	void IgnoreTimeChanged(int state);
 	void RepeatChanged(int state);
 	void UpdateOnRepeatChanged(int state);
-	void DurationChanged(double seconds);
-	void DurationUnitChanged(DurationUnit unit);
+	void DurationChanged(const Duration &seconds);
 	void AdvancedSettingsToggleClicked();
 	void ShowNextMatch();
 	void UpdateCurrentTime();
@@ -149,3 +150,5 @@ private:
 	QTimer _timer;
 	bool _loading = true;
 };
+
+} // namespace advss
