@@ -1,5 +1,5 @@
 #pragma once
-#include "macro.hpp"
+#include "macro-condition-edit.hpp"
 #include "file-selection.hpp"
 #include "variable-text-edit.hpp"
 #include "regex-config.hpp"
@@ -11,6 +11,8 @@
 #include <QPushButton>
 #include <QCheckBox>
 
+namespace advss {
+
 class MacroConditionFile : public MacroCondition {
 public:
 	MacroConditionFile(Macro *m) : MacroCondition(m, true) {}
@@ -35,9 +37,8 @@ public:
 		DATE_CHANGE,
 	};
 
-	std::string _file = obs_module_text("AdvSceneSwitcher.enterPath");
-	VariableResolvingString _text =
-		obs_module_text("AdvSceneSwitcher.enterText");
+	StringVariable _file = obs_module_text("AdvSceneSwitcher.enterPath");
+	StringVariable _text = obs_module_text("AdvSceneSwitcher.enterText");
 	FileType _fileType = FileType::LOCAL;
 	ConditionType _condition = ConditionType::MATCH;
 	RegexConfig _regex;
@@ -101,3 +102,5 @@ private:
 
 	bool _loading = true;
 };
+
+} // namespace advss
