@@ -1,7 +1,8 @@
-#include "macro-condition-edit.hpp"
 #include "macro-condition-idle.hpp"
+#include "platform-funcs.hpp"
 #include "utility.hpp"
-#include "advanced-scene-switcher.hpp"
+
+namespace advss {
 
 const std::string MacroConditionIdle::id = "idle";
 
@@ -12,9 +13,9 @@ bool MacroConditionIdle::_registered = MacroConditionFactory::Register(
 
 bool MacroConditionIdle::CheckCondition()
 {
-	auto seconds = secondsSinceLastInput();
+	auto seconds = SecondsSinceLastInput();
 	SetVariableValue(std::to_string(seconds));
-	return seconds >= _duration.seconds;
+	return seconds >= _duration.Seconds();
 }
 
 bool MacroConditionIdle::Save(obs_data_t *obj) const
@@ -37,16 +38,14 @@ MacroConditionIdleEdit::MacroConditionIdleEdit(
 {
 	_duration = new DurationSelection();
 
-	QWidget::connect(_duration, SIGNAL(DurationChanged(double)), this,
-			 SLOT(DurationChanged(double)));
-	QWidget::connect(_duration, SIGNAL(UnitChanged(DurationUnit)), this,
-			 SLOT(DurationUnitChanged(DurationUnit)));
+	QWidget::connect(_duration, SIGNAL(DurationChanged(const Duration &)),
+			 this, SLOT(DurationChanged(const Duration &)));
 
 	QHBoxLayout *mainLayout = new QHBoxLayout;
 	std::unordered_map<std::string, QWidget *> widgetPlaceholders = {
 		{"{{duration}}", _duration},
 	};
-	placeWidgets(obs_module_text("AdvSceneSwitcher.condition.idle.entry"),
+	PlaceWidgets(obs_module_text("AdvSceneSwitcher.condition.idle.entry"),
 		     mainLayout, widgetPlaceholders);
 	setLayout(mainLayout);
 
@@ -55,24 +54,14 @@ MacroConditionIdleEdit::MacroConditionIdleEdit(
 	_loading = false;
 }
 
-void MacroConditionIdleEdit::DurationChanged(double seconds)
+void MacroConditionIdleEdit::DurationChanged(const Duration &dur)
 {
 	if (_loading || !_entryData) {
 		return;
 	}
 
-	std::lock_guard<std::mutex> lock(switcher->m);
-	_entryData->_duration.seconds = seconds;
-}
-
-void MacroConditionIdleEdit::DurationUnitChanged(DurationUnit unit)
-{
-	if (_loading || !_entryData) {
-		return;
-	}
-
-	std::lock_guard<std::mutex> lock(switcher->m);
-	_entryData->_duration.displayUnit = unit;
+	auto lock = LockContext();
+	_entryData->_duration = dur;
 }
 
 void MacroConditionIdleEdit::UpdateEntryData()
@@ -83,3 +72,5 @@ void MacroConditionIdleEdit::UpdateEntryData()
 
 	_duration->SetDuration(_entryData->_duration);
 }
+
+} // namespace advss
