@@ -1,7 +1,8 @@
-#include "macro-condition-edit.hpp"
 #include "macro-condition-media.hpp"
+#include "switcher-data.hpp"
 #include "utility.hpp"
-#include "advanced-scene-switcher.hpp"
+
+namespace advss {
 
 const std::string MacroConditionMedia::id = "media";
 
@@ -71,18 +72,18 @@ bool MacroConditionMedia::CheckTime()
 		match = true;
 		break;
 	case Time::TIME_RESTRICTION_SHORTER:
-		match = currentTime < _time.seconds * 1000;
+		match = currentTime < _time.Milliseconds();
 		break;
 	case Time::TIME_RESTRICTION_LONGER:
-		match = currentTime > _time.seconds * 1000;
+		match = currentTime > _time.Milliseconds();
 		break;
 	case Time::TIME_RESTRICTION_REMAINING_SHORTER:
 		match = duration > currentTime &&
-			duration - currentTime < _time.seconds * 1000;
+			duration - currentTime < _time.Milliseconds();
 		break;
 	case Time::TIME_RESTRICTION_REMAINING_LONGER:
 		match = duration > currentTime &&
-			duration - currentTime > _time.seconds * 1000;
+			duration - currentTime > _time.Milliseconds();
 		break;
 	default:
 		break;
@@ -429,10 +430,8 @@ MacroConditionMediaEdit::MacroConditionMediaEdit(
 			 SLOT(StateChanged(int)));
 	QWidget::connect(_timeRestrictions, SIGNAL(currentIndexChanged(int)),
 			 this, SLOT(TimeRestrictionChanged(int)));
-	QWidget::connect(_time, SIGNAL(DurationChanged(double)), this,
-			 SLOT(TimeChanged(double)));
-	QWidget::connect(_time, SIGNAL(UnitChanged(DurationUnit)), this,
-			 SLOT(TimeUnitChanged(DurationUnit)));
+	QWidget::connect(_time, SIGNAL(DurationChanged(const Duration &)), this,
+			 SLOT(TimeChanged(const Duration &)));
 	QWidget::connect(_onChange, SIGNAL(stateChanged(int)), this,
 			 SLOT(OnChangeChanged(int)));
 
@@ -449,7 +448,7 @@ MacroConditionMediaEdit::MacroConditionMediaEdit(
 		{"{{timeRestrictions}}", _timeRestrictions},
 		{"{{time}}", _time},
 	};
-	placeWidgets(obs_module_text("AdvSceneSwitcher.condition.media.entry"),
+	PlaceWidgets(obs_module_text("AdvSceneSwitcher.condition.media.entry"),
 		     entryLayout, widgetPlaceholders);
 	QVBoxLayout *mainLayout = new QVBoxLayout;
 	mainLayout->addLayout(entryLayout);
@@ -467,7 +466,7 @@ void MacroConditionMediaEdit::SourceTypeChanged(int idx)
 		return;
 	}
 
-	std::lock_guard<std::mutex> lock(switcher->m);
+	auto lock = LockContext();
 	_entryData->_sourceType = static_cast<MacroConditionMedia::Type>(
 		_sourceTypes->itemData(idx).toInt());
 
@@ -488,7 +487,7 @@ void MacroConditionMediaEdit::SourceChanged(const SourceSelection &source)
 		return;
 	}
 
-	std::lock_guard<std::mutex> lock(switcher->m);
+	auto lock = LockContext();
 	_entryData->_sourceGroup.clear();
 	_entryData->_sourceType = MacroConditionMedia::Type::SOURCE;
 	_entryData->ClearSignalHandler();
@@ -505,7 +504,7 @@ void MacroConditionMediaEdit::SceneChanged(const SceneSelection &s)
 		return;
 	}
 
-	std::lock_guard<std::mutex> lock(switcher->m);
+	auto lock = LockContext();
 	_entryData->_scene = s;
 	_entryData->UpdateMediaSourcesOfSceneList();
 	emit HeaderInfoChanged(
@@ -532,7 +531,7 @@ void MacroConditionMediaEdit::StateChanged(int index)
 		return;
 	}
 
-	std::lock_guard<std::mutex> lock(switcher->m);
+	auto lock = LockContext();
 	_entryData->_state = getMediaStateFromIdx(index);
 	if (_entryData->_sourceType != MacroConditionMedia::Type::SOURCE) {
 		_entryData->UpdateMediaSourcesOfSceneList();
@@ -552,7 +551,7 @@ void MacroConditionMediaEdit::TimeRestrictionChanged(int index)
 		_time->setDisabled(false);
 	}
 
-	std::lock_guard<std::mutex> lock(switcher->m);
+	auto lock = LockContext();
 	_entryData->_restriction =
 		static_cast<MacroConditionMedia::Time>(index);
 	if (_entryData->_sourceType != MacroConditionMedia::Type::SOURCE) {
@@ -560,27 +559,14 @@ void MacroConditionMediaEdit::TimeRestrictionChanged(int index)
 	}
 }
 
-void MacroConditionMediaEdit::TimeChanged(double seconds)
+void MacroConditionMediaEdit::TimeChanged(const Duration &dur)
 {
 	if (_loading || !_entryData) {
 		return;
 	}
 
-	std::lock_guard<std::mutex> lock(switcher->m);
-	_entryData->_time.seconds = seconds;
-	if (_entryData->_sourceType != MacroConditionMedia::Type::SOURCE) {
-		_entryData->UpdateMediaSourcesOfSceneList();
-	}
-}
-
-void MacroConditionMediaEdit::TimeUnitChanged(DurationUnit unit)
-{
-	if (_loading || !_entryData) {
-		return;
-	}
-
-	std::lock_guard<std::mutex> lock(switcher->m);
-	_entryData->_time.displayUnit = unit;
+	auto lock = LockContext();
+	_entryData->_time = dur;
 	if (_entryData->_sourceType != MacroConditionMedia::Type::SOURCE) {
 		_entryData->UpdateMediaSourcesOfSceneList();
 	}
@@ -592,7 +578,7 @@ void MacroConditionMediaEdit::OnChangeChanged(int value)
 		return;
 	}
 
-	std::lock_guard<std::mutex> lock(switcher->m);
+	auto lock = LockContext();
 	_entryData->_onlyMatchOnChagne = value;
 	if (_entryData->_sourceType != MacroConditionMedia::Type::SOURCE) {
 		_entryData->UpdateMediaSourcesOfSceneList();
@@ -610,7 +596,7 @@ void MacroConditionMediaEdit::SetWidgetVisibility()
 	}
 }
 
-int getIdxFromMediaState(MacroConditionMedia::State state)
+static int getIdxFromMediaState(MacroConditionMedia::State state)
 {
 	if (state < MacroConditionMedia::State::LAST_OBS_MEDIA_STATE) {
 		return static_cast<int>(state);
@@ -642,3 +628,5 @@ void MacroConditionMediaEdit::UpdateEntryData()
 	_onChange->setChecked(_entryData->_onlyMatchOnChagne);
 	SetWidgetVisibility();
 }
+
+} // namespace advss
