@@ -1,5 +1,5 @@
 #pragma once
-#include "macro.hpp"
+#include "macro-condition-edit.hpp"
 #include "duration-control.hpp"
 #include "scene-selection.hpp"
 #include "source-selection.hpp"
@@ -9,6 +9,8 @@
 #include <QComboBox>
 #include <QCheckBox>
 
+namespace advss {
+
 constexpr auto custom_media_states_offset = 100;
 
 class MacroConditionMedia : public MacroCondition {
@@ -116,8 +118,7 @@ private slots:
 	void SceneChanged(const SceneSelection &);
 	void StateChanged(int index);
 	void TimeRestrictionChanged(int index);
-	void TimeChanged(double seconds);
-	void TimeUnitChanged(DurationUnit unit);
+	void TimeChanged(const Duration &seconds);
 	void OnChangeChanged(int);
 signals:
 	void HeaderInfoChanged(const QString &);
@@ -136,3 +137,5 @@ private:
 	void SetWidgetVisibility();
 	bool _loading = true;
 };
+
+} // namespace advss
