@@ -1,7 +1,7 @@
-#include "macro-condition-edit.hpp"
 #include "macro-condition-profile.hpp"
 #include "utility.hpp"
-#include "advanced-scene-switcher.hpp"
+
+namespace advss {
 
 const std::string MacroConditionProfile::id = "profile";
 
@@ -41,7 +41,7 @@ MacroConditionProfileEdit::MacroConditionProfileEdit(
 	QWidget *parent, std::shared_ptr<MacroConditionProfile> entryData)
 	: QWidget(parent), _profiles(new QComboBox())
 {
-	populateProfileSelection(_profiles);
+	PopulateProfileSelection(_profiles);
 	QWidget::connect(_profiles, SIGNAL(currentTextChanged(const QString &)),
 			 this, SLOT(ProfileChanged(const QString &)));
 
@@ -51,7 +51,7 @@ MacroConditionProfileEdit::MacroConditionProfileEdit(
 		{"{{profiles}}", _profiles},
 	};
 
-	placeWidgets(
+	PlaceWidgets(
 		obs_module_text("AdvSceneSwitcher.condition.profile.entry"),
 		mainLayout, widgetPlaceholders);
 	setLayout(mainLayout);
@@ -67,7 +67,7 @@ void MacroConditionProfileEdit::ProfileChanged(const QString &text)
 		return;
 	}
 
-	std::lock_guard<std::mutex> lock(switcher->m);
+	auto lock = LockContext();
 	_entryData->_profile = text.toStdString();
 	emit HeaderInfoChanged(
 		QString::fromStdString(_entryData->GetShortDesc()));
@@ -81,3 +81,5 @@ void MacroConditionProfileEdit::UpdateEntryData()
 
 	_profiles->setCurrentText(QString::fromStdString(_entryData->_profile));
 }
+
+} // namespace advss
