@@ -1,8 +1,11 @@
 #pragma once
-#include "macro.hpp"
+#include "macro-condition-edit.hpp"
+
 #include <QWidget>
 #include <QComboBox>
 
+namespace advss {
+
 enum class RecordState {
 	STOP,
 	PAUSE,
@@ -54,3 +57,5 @@ protected:
 private:
 	bool _loading = true;
 };
+
+} // namespace advss
