@@ -1,5 +1,5 @@
 #pragma once
-#include "macro.hpp"
+#include "macro-condition-edit.hpp"
 #include "scene-selection.hpp"
 #include "scene-item-selection.hpp"
 #include "variable-text-edit.hpp"
@@ -8,9 +8,11 @@
 #include <QSpinBox>
 #include <QCheckBox>
 
+namespace advss {
+
 class MacroConditionSceneTransform : public MacroCondition {
 public:
-	MacroConditionSceneTransform(Macro *m) : MacroCondition(m) {}
+	MacroConditionSceneTransform(Macro *m) : MacroCondition(m, true) {}
 	bool CheckCondition();
 	bool Save(obs_data_t *obj) const;
 	bool Load(obs_data_t *obj);
@@ -24,7 +26,7 @@ public:
 	SceneSelection _scene;
 	SceneItemSelection _source;
 	RegexConfig _regex;
-	VariableResolvingString _settings = "";
+	StringVariable _settings = "";
 
 private:
 	static bool _registered;
@@ -70,3 +72,5 @@ protected:
 private:
 	bool _loading = true;
 };
+
+} // namespace advss
