@@ -1,5 +1,5 @@
 #pragma once
-#include "macro.hpp"
+#include "macro-condition-edit.hpp"
 #include "resizing-text-edit.hpp"
 #include "variable.hpp"
 #include "regex-config.hpp"
@@ -9,6 +9,8 @@
 #include <QLineEdit>
 #include <QCheckBox>
 
+namespace advss {
+
 class MacroConditionVariable : public MacroCondition {
 public:
 	MacroConditionVariable(Macro *m) : MacroCondition(m) {}
@@ -35,8 +37,8 @@ public:
 	};
 
 	Type _type = Type::EQUALS;
-	std::string _variableName = "";
-	std::string _variable2Name = "";
+	std::weak_ptr<Variable> _variable;
+	std::weak_ptr<Variable> _variable2;
 	std::string _strValue = "";
 	double _numValue = 0;
 	RegexConfig _regex;
@@ -94,3 +96,5 @@ private:
 
 	bool _loading = true;
 };
+
+} // namespace advss
