@@ -1,11 +1,13 @@
 #pragma once
-#include "macro.hpp"
+#include "macro-condition-edit.hpp"
 #include "connection-manager.hpp"
 #include "variable-text-edit.hpp"
 #include "regex-config.hpp"
 
 #include <QCheckBox>
 
+namespace advss {
+
 class MacroConditionWebsocket : public MacroCondition {
 public:
 	MacroConditionWebsocket(Macro *m) : MacroCondition(m, true) {}
@@ -25,10 +27,9 @@ public:
 	};
 
 	Type _type = Type::REQUEST;
-	VariableResolvingString _message =
-		obs_module_text("AdvSceneSwitcher.enterText");
+	StringVariable _message = obs_module_text("AdvSceneSwitcher.enterText");
 	RegexConfig _regex;
-	std::string _connection;
+	std::weak_ptr<Connection> _connection;
 
 private:
 	static bool _registered;
@@ -74,3 +75,5 @@ private:
 	QHBoxLayout *_editLayout;
 	bool _loading = true;
 };
+
+} // namespace advss
