@@ -3,6 +3,8 @@
 #include "macro-ref.hpp"
 #include <duration-control.hpp>
 
+namespace advss {
+
 constexpr auto logic_root_offset = 100;
 
 enum class LogicType {
@@ -39,15 +41,12 @@ public:
 	};
 
 	void Save(obs_data_t *obj, const char *condName = "time_constraint",
-		  const char *secondsName = "seconds",
-		  const char *unitName = "displayUnit") const;
+		  const char *duration = "seconds") const;
 	void Load(obs_data_t *obj, const char *condName = "time_constraint",
-		  const char *secondsName = "seconds",
-		  const char *unitName = "displayUnit");
+		  const char *duration = "seconds");
 	void SetModifier(Type cond) { _type = cond; }
 	void SetTimeRemaining(const double &val) { _dur.SetTimeRemaining(val); }
-	void SetValue(double value) { _dur.seconds = value; }
-	void SetUnit(DurationUnit u) { _dur.displayUnit = u; }
+	void SetValue(const Duration &value) { _dur = value; }
 	Type GetType() { return _type; }
 	Duration GetDuration() { return _dur; }
 	bool DurationReached();
@@ -73,8 +72,7 @@ public:
 	void CheckDurationModifier(bool &val);
 	DurationModifier GetDurationModifier() { return _duration; }
 	void SetDurationModifier(DurationModifier::Type m);
-	void SetDurationUnit(DurationUnit u);
-	void SetDuration(double seconds);
+	void SetDuration(const Duration &duration);
 
 private:
 	LogicType _logic = LogicType::ROOT_NONE;
@@ -84,13 +82,17 @@ private:
 class MacroRefCondition : virtual public MacroCondition {
 public:
 	MacroRefCondition(Macro *m, bool supportsVariableValue = false);
-	void ResolveMacroRef();
+	bool PostLoad() override;
+
 	MacroRef _macro;
 };
 
 class MultiMacroRefCondtition : virtual public MacroCondition {
 public:
 	MultiMacroRefCondtition(Macro *m, bool supportsVariableValue = false);
-	void ResolveMacroRef();
+	bool PostLoad() override;
+
 	std::vector<MacroRef> _macros;
 };
+
+} // namespace advss
