@@ -10,6 +10,8 @@
 #include <QScrollBar>
 #include <QtGlobal>
 
+namespace advss {
+
 MacroSegmentList::MacroSegmentList(QWidget *parent)
 	: QScrollArea(parent),
 	  _layout(new QVBoxLayout),
@@ -75,7 +77,7 @@ void MacroSegmentList::SetHelpMsgVisible(bool visible)
 	_helpMsg->setVisible(visible);
 }
 
-void MacroSegmentList::Insert(int idx, QWidget *widget)
+void MacroSegmentList::Insert(int idx, MacroSegmentEdit *widget)
 {
 	widget->installEventFilter(this);
 	_contentLayout->insertWidget(idx, widget);
@@ -89,12 +91,12 @@ void MacroSegmentList::Add(QWidget *widget)
 
 void MacroSegmentList::Remove(int idx)
 {
-	deleteLayoutItemWidget(_contentLayout->takeAt(idx));
+	DeleteLayoutItemWidget(_contentLayout->takeAt(idx));
 }
 
 void MacroSegmentList::Clear(int idx)
 {
-	clearLayout(_contentLayout, idx);
+	ClearLayout(_contentLayout, idx);
 }
 
 void MacroSegmentList::Highlight(int idx, QColor color)
@@ -135,8 +137,6 @@ void MacroSegmentList::SetSelection(int idx)
 
 bool MacroSegmentList::eventFilter(QObject *object, QEvent *event)
 {
-	if (event->type() == QEvent::MouseButtonPress) {
-	}
 	switch (event->type()) {
 	case QEvent::MouseButtonPress:
 		mousePressEvent(static_cast<QMouseEvent *>(event));
@@ -237,14 +237,14 @@ void MacroSegmentList::HideLastDropLine()
 	_dropLineIdx = -1;
 }
 
-bool isInUpperHalfOf(const QPoint &pos, const QRect &rect)
+static bool isInUpperHalfOf(const QPoint &pos, const QRect &rect)
 {
 	return QRect(rect.topLeft(),
 		     QSize(rect.size().width(), rect.size().height() / 2))
 		.contains(pos);
 }
 
-bool widgetIsInLayout(QWidget *w, QLayout *l)
+static bool widgetIsInLayout(QWidget *w, QLayout *l)
 {
 	if (w == nullptr) {
 		return false;
@@ -441,3 +441,5 @@ void MacroSegmentList::dropEvent(QDropEvent *event)
 #endif
 	_dragPosition = -1;
 }
+
+} // namespace advss
