@@ -1,12 +1,16 @@
 #include "macro-segment.hpp"
 #include "section.hpp"
 #include "utility.hpp"
+#include "mouse-wheel-guard.hpp"
 
 #include <obs.hpp>
 #include <QEvent>
 #include <QMouseEvent>
 #include <QLabel>
 #include <QScrollBar>
+#include <QApplication>
+
+namespace advss {
 
 MacroSegment::MacroSegment(Macro *m, bool supportsVariableValue)
 	: _macro(m), _supportsVariableValue(supportsVariableValue)
@@ -80,22 +84,6 @@ void MacroSegment::DecrementVariableRef()
 	_variableRefs--;
 }
 
-MouseWheelWidgetAdjustmentGuard::MouseWheelWidgetAdjustmentGuard(QObject *parent)
-	: QObject(parent)
-{
-}
-
-bool MouseWheelWidgetAdjustmentGuard::eventFilter(QObject *o, QEvent *e)
-{
-	const QWidget *widget = static_cast<QWidget *>(o);
-	if (e->type() == QEvent::Wheel && widget && !widget->hasFocus()) {
-		e->ignore();
-		return true;
-	}
-
-	return QObject::eventFilter(o, e);
-}
-
 MacroSegmentEdit::MacroSegmentEdit(bool highlight, QWidget *parent)
 	: QWidget(parent),
 	  _section(new Section(300)),
@@ -182,11 +170,37 @@ MacroSegmentEdit::MacroSegmentEdit(bool highlight, QWidget *parent)
 	SetSelected(false);
 	ShowDropLine(DropLineState::NONE);
 
+	// Enable dragging while clicking on the header text
+	_headerInfo->installEventFilter(this);
+
 	_timer.setInterval(1500);
 	connect(&_timer, SIGNAL(timeout()), this, SLOT(Highlight()));
 	_timer.start();
 }
 
+bool MacroSegmentEdit::eventFilter(QObject *obj, QEvent *ev)
+{
+	if (obj == _headerInfo && ev->type() == QEvent::MouseMove) {
+		if (!parentWidget()) {
+			return QWidget::eventFilter(obj, ev);
+		}
+		// Generate a mouse move event for the MacroSegmentList
+		QMouseEvent *mouseEvent = static_cast<QMouseEvent *>(ev);
+		QMouseEvent *newEvent = new QMouseEvent(
+			mouseEvent->type(),
+			_headerInfo->mapTo(this, mouseEvent->pos()),
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+			mouseEvent->globalPos(),
+#else
+			mouseEvent->globalPosition(),
+#endif
+			mouseEvent->button(), mouseEvent->buttons(),
+			mouseEvent->modifiers());
+		QApplication::sendEvent(parentWidget(), newEvent);
+	}
+	return QWidget::eventFilter(obj, ev);
+}
+
 void MacroSegmentEdit::HeaderInfoChanged(const QString &text)
 {
 	_headerInfo->setVisible(!text.isEmpty());
@@ -220,13 +234,7 @@ void MacroSegmentEdit::SetFocusPolicyOfWidgets()
 {
 	QList<QWidget *> widgets = this->findChildren<QWidget *>();
 	for (auto w : widgets) {
-		w->setFocusPolicy(Qt::StrongFocus);
-		// Ignore QScrollBar as there is no danger of accidentally modifying anything
-		// and long expanded QComboBox would be difficult to interact with otherwise.
-		if (qobject_cast<QScrollBar *>(w)) {
-			continue;
-		}
-		w->installEventFilter(new MouseWheelWidgetAdjustmentGuard(w));
+		PreventMouseWheelAdjustWithoutFocus(w);
 	}
 }
 
@@ -265,3 +273,5 @@ void MacroSegmentEdit::ShowDropLine(DropLineState state)
 		break;
 	}
 }
+
+} // namespace advss
