@@ -30,7 +30,12 @@ Macro::~Macro()
 	_die = true;
 	Stop();
 	ClearHotkeys();
-	RemoveDock();
+
+	// Keep the dock widgets in case of shutdown so they can be restored by
+	// OBS on startup
+	if (!switcher->obsIsShuttingDown) {
+		RemoveDock();
+	}
 }
 
 std::shared_ptr<Macro>
@@ -171,21 +176,14 @@ bool Macro::CeckMatch()
 	}
 	vblog(LOG_INFO, "Macro %s returned %d", _name.c_str(), _matched);
 
-	bool newLastMatched = _matched;
-	if (_matched && _matchOnChange && _lastMatched == _matched) {
+	bool matchedBeforeOnChangeCheck = _matched;
+	if (_matched && _matchOnChange && _lastMatched) {
 		vblog(LOG_INFO, "ignore match for Macro %s (on change)",
 		      _name.c_str());
 		_matched = false;
 		SetOnChangeHighlight();
 	}
-	_lastMatched = newLastMatched;
-
-	// TODO: Move back to PerformAction() once new scene collection frontend
-	// events are available - see:
-	// https://github.com/obsproject/obs-studio/commit/feda1aaa283e8a99f6ba1159cfe6b9c1f2934a61
-	if (_matched && _runCount != std::numeric_limits<int>::max()) {
-		_runCount++;
-	}
+	_lastMatched = matchedBeforeOnChangeCheck;
 	_lastCheckTime = std::chrono::high_resolution_clock::now();
 	return _matched;
 }
@@ -208,14 +206,23 @@ bool Macro::PerformActions(bool forceParallel, bool ignorePause)
 	} else {
 		RunActions(ret, ignorePause);
 	}
-	_wasExecutedRecently = true;
+	_lastExecutionTime = std::chrono::high_resolution_clock::now();
 	auto group = _parent.lock();
 	if (group) {
-		group->_wasExecutedRecently = true;
+		group->_lastExecutionTime = _lastExecutionTime;
+	}
+	if (_runCount != std::numeric_limits<int>::max()) {
+		_runCount++;
 	}
 	return ret;
 }
 
+bool Macro::ExecutedSince(
+	const std::chrono::high_resolution_clock::time_point &time)
+{
+	return _lastExecutionTime > time;
+}
+
 int64_t Macro::MsSinceLastCheck() const
 {
 	if (_lastCheckTime.time_since_epoch().count() == 0) {
@@ -241,19 +248,27 @@ void Macro::ResetTimers()
 		c->ResetDuration();
 	}
 	_lastCheckTime = {};
+	_lastExecutionTime = {};
 }
 
 void Macro::RunActions(bool &retVal, bool ignorePause)
 {
 	bool ret = true;
 	for (auto &a : _actions) {
-		a->LogAction();
-		ret = ret && a->PerformAction();
+		if (a->Enabled()) {
+			a->LogAction();
+			ret = ret && a->PerformAction();
+		} else {
+			vblog(LOG_INFO, "skipping disabled action %s",
+			      a->GetId().c_str());
+		}
 		if (!ret || (_paused && !ignorePause) || _stop || _die) {
 			retVal = ret;
 			break;
 		}
-		a->SetHighlight();
+		if (a->Enabled()) {
+			a->SetHighlight();
+		}
 	}
 	_done = true;
 }
@@ -346,6 +361,7 @@ bool Macro::Save(obs_data_t *obj) const
 	obs_data_set_bool(obj, "pause", _paused);
 	obs_data_set_bool(obj, "parallel", _runInParallel);
 	obs_data_set_bool(obj, "onChange", _matchOnChange);
+	obs_data_set_bool(obj, "skipExecOnStart", _skipExecOnStart);
 
 	obs_data_set_bool(obj, "group", _isGroup);
 	if (_isGroup) {
@@ -438,6 +454,7 @@ bool Macro::Load(obs_data_t *obj)
 	_paused = obs_data_get_bool(obj, "pause");
 	_runInParallel = obs_data_get_bool(obj, "parallel");
 	_matchOnChange = obs_data_get_bool(obj, "onChange");
+	_skipExecOnStart = obs_data_get_bool(obj, "skipExecOnStart");
 
 	_isGroup = obs_data_get_bool(obj, "group");
 	if (_isGroup) {
@@ -543,15 +560,6 @@ bool Macro::SwitchesScene() const
 	return false;
 }
 
-bool Macro::WasExecutedRecently()
-{
-	if (_wasExecutedRecently) {
-		_wasExecutedRecently = false;
-		return true;
-	}
-	return false;
-}
-
 bool Macro::OnChangePreventedActionsRecently()
 {
 	if (_onChangeTriggered) {
@@ -601,12 +609,16 @@ void Macro::SaveDockSettings(obs_data_t *obj) const
 	}
 	obs_data_set_bool(dockSettings, "hasRunButton", _dockHasRunButton);
 	obs_data_set_bool(dockSettings, "hasPauseButton", _dockHasPauseButton);
-	obs_data_set_string(dockSettings, "runButtonText",
-			    _runButtonText.c_str());
-	obs_data_set_string(dockSettings, "pauseButtonText",
-			    _pauseButtonText.c_str());
-	obs_data_set_string(dockSettings, "unpauseButtonText",
-			    _unpauseButtonText.c_str());
+	obs_data_set_bool(dockSettings, "hasStatusLabel", _dockHasStatusLabel);
+	obs_data_set_bool(dockSettings, "highlightIfConditionsTrue",
+			  _dockHighlight);
+	_runButtonText.Save(dockSettings, "runButtonText");
+	_pauseButtonText.Save(dockSettings, "pauseButtonText");
+	_unpauseButtonText.Save(dockSettings, "unpauseButtonText");
+	_conditionsTrueStatusText.Save(dockSettings,
+				       "conditionsTrueStatusText");
+	_conditionsFalseStatusText.Save(dockSettings,
+					"conditionsFalseStatusText");
 	if (_dock) {
 		auto window = static_cast<QMainWindow *>(
 			obs_frontend_get_main_window());
@@ -648,16 +660,22 @@ void Macro::LoadDockSettings(obs_data_t *obj)
 	obs_data_set_default_string(
 		dockSettings, "unpauseButtonText",
 		obs_module_text("AdvSceneSwitcher.macroDock.unpause"));
-
-	_runButtonText = obs_data_get_string(dockSettings, "runButtonText");
-	_pauseButtonText = obs_data_get_string(dockSettings, "pauseButtonText");
-	_unpauseButtonText =
-		obs_data_get_string(dockSettings, "unpauseButtonText");
+	_runButtonText.Load(dockSettings, "runButtonText");
+	_pauseButtonText.Load(dockSettings, "pauseButtonText");
+	_unpauseButtonText.Load(dockSettings, "unpauseButtonText");
+	_conditionsTrueStatusText.Load(dockSettings,
+				       "conditionsTrueStatusText");
+	_conditionsFalseStatusText.Load(dockSettings,
+					"conditionsFalseStatusText");
 	if (dockEnabled) {
 		_dockHasRunButton =
 			obs_data_get_bool(dockSettings, "hasRunButton");
 		_dockHasPauseButton =
 			obs_data_get_bool(dockSettings, "hasPauseButton");
+		_dockHasStatusLabel =
+			obs_data_get_bool(dockSettings, "hasStatusLabel");
+		_dockHighlight = obs_data_get_bool(dockSettings,
+						   "highlightIfConditionsTrue");
 		_dockIsFloating = obs_data_get_bool(dockSettings, "isFloating");
 		_dockArea = static_cast<Qt::DockWidgetArea>(
 			obs_data_get_int(dockSettings, "area"));
@@ -692,10 +710,9 @@ void Macro::EnableDock(bool value)
 	// Create new dock widget
 	auto window =
 		static_cast<QMainWindow *>(obs_frontend_get_main_window());
-	_dock = new MacroDock(this, window,
-			      QString::fromStdString(_runButtonText),
-			      QString::fromStdString(_pauseButtonText),
-			      QString::fromStdString(_unpauseButtonText));
+	_dock = new MacroDock(this, window, _runButtonText, _pauseButtonText,
+			      _unpauseButtonText, _conditionsTrueStatusText,
+			      _conditionsFalseStatusText, _dockHighlight);
 	SetDockWidgetName(); // Used by OBS to restore position
 
 	// Register new dock
@@ -705,14 +722,16 @@ void Macro::EnableDock(bool value)
 	// geometry set here.
 	// The function calls here are only intended to attempt to restore the
 	// dock status when switching scene collections.
-	_dock->setVisible(_dockIsVisible);
-	if (window->dockWidgetArea(_dock) != _dockArea) {
-		window->addDockWidget(_dockArea, _dock);
+	if (switcher->startupLoadDone) {
+		_dock->setVisible(_dockIsVisible);
+		if (window->dockWidgetArea(_dock) != _dockArea) {
+			window->addDockWidget(_dockArea, _dock);
+		}
+		if (_dock->isFloating() != _dockIsFloating) {
+			_dock->setFloating(_dockIsFloating);
+		}
+		_dock->restoreGeometry(_dockGeo);
 	}
-	if (_dock->isFloating() != _dockIsFloating) {
-		_dock->setFloating(_dockIsFloating);
-	}
-	_dock->restoreGeometry(_dockGeo);
 	_registerDock = value;
 }
 
@@ -734,13 +753,31 @@ void Macro::SetDockHasPauseButton(bool value)
 	_dock->ShowPauseButton(value);
 }
 
+void Macro::SetDockHasStatusLabel(bool value)
+{
+	_dockHasStatusLabel = value;
+	if (!_dock) {
+		return;
+	}
+	_dock->ShowStatusLabel(value);
+}
+
+void Macro::SetHighlightEnable(bool value)
+{
+	_dockHighlight = value;
+	if (!_dock) {
+		return;
+	}
+	_dock->EnableHighlight(value);
+}
+
 void Macro::SetRunButtonText(const std::string &text)
 {
 	_runButtonText = text;
 	if (!_dock) {
 		return;
 	}
-	_dock->SetRunButtonText(QString::fromStdString(text));
+	_dock->SetRunButtonText(text);
 }
 
 void Macro::SetPauseButtonText(const std::string &text)
@@ -749,7 +786,7 @@ void Macro::SetPauseButtonText(const std::string &text)
 	if (!_dock) {
 		return;
 	}
-	_dock->SetPauseButtonText(QString::fromStdString(text));
+	_dock->SetPauseButtonText(text);
 }
 
 void Macro::SetUnpauseButtonText(const std::string &text)
@@ -758,7 +795,35 @@ void Macro::SetUnpauseButtonText(const std::string &text)
 	if (!_dock) {
 		return;
 	}
-	_dock->SetUnpauseButtonText(QString::fromStdString(text));
+	_dock->SetUnpauseButtonText(text);
+}
+
+void Macro::SetConditionsTrueStatusText(const std::string &text)
+{
+	_conditionsTrueStatusText = text;
+	if (!_dock) {
+		return;
+	}
+	_dock->SetConditionsTrueText(text);
+}
+
+StringVariable Macro::ConditionsTrueStatusText() const
+{
+	return _conditionsTrueStatusText;
+}
+
+void Macro::SetConditionsFalseStatusText(const std::string &text)
+{
+	_conditionsFalseStatusText = text;
+	if (!_dock) {
+		return;
+	}
+	_dock->SetConditionsFalseText(text);
+}
+
+StringVariable Macro::ConditionsFalseStatusText() const
+{
+	return _conditionsFalseStatusText;
 }
 
 void Macro::RemoveDock()
@@ -963,7 +1028,7 @@ bool SwitcherData::CheckMacros()
 
 bool SwitcherData::RunMacros()
 {
-	// Create copy of macor list as elements might be removed, inserted, or
+	// Create copy of macro list as elements might be removed, inserted, or
 	// reordered while macros are currently being executed.
 	// For example, this can happen if a macro is performing a wait action,
 	// as the main lock will be unlocked during this time.
@@ -984,12 +1049,18 @@ bool SwitcherData::RunMacros()
 	}
 
 	for (auto &m : runPhaseMacros) {
-		if (m && m->Matched()) {
-			vblog(LOG_INFO, "running macro: %s", m->Name().c_str());
-			if (!m->PerformActions()) {
-				blog(LOG_WARNING, "abort macro: %s",
-				     m->Name().c_str());
-			}
+		if (!m || !m->Matched()) {
+			continue;
+		}
+		if (firstInterval && m->SkipExecOnStart()) {
+			blog(LOG_INFO,
+			     "skip execution of macro \"%s\" at startup",
+			     m->Name().c_str());
+			continue;
+		}
+		vblog(LOG_INFO, "running macro: %s", m->Name().c_str());
+		if (!m->PerformActions()) {
+			blog(LOG_WARNING, "abort macro: %s", m->Name().c_str());
 		}
 	}
 	if (GetLock()) {
