@@ -13,6 +13,8 @@
 #include <map>
 #include <thread>
 
+namespace advss {
+
 bool canSimulateKeyPresses = false;
 
 std::chrono::high_resolution_clock::time_point lastMouseLeftClickTime{};
@@ -76,28 +78,38 @@ void GetCurrentWindowTitle(std::string &title)
 		for (NSDictionary *app in apps) {
 			int layer =
 				[[app objectForKey:@"kCGWindowLayer"] intValue];
-			// True if window is frontmost
-			if (layer == 0) {
-				std::string name(
-					[[app objectForKey:@"kCGWindowName"]
-						UTF8String],
-					[[app objectForKey:@"kCGWindowName"]
-						lengthOfBytesUsingEncoding:
-							NSUTF8StringEncoding]);
-				std::string owner(
-					[[app objectForKey:@"kCGWindowOwnerName"]
-						UTF8String],
-					[[app objectForKey:@"kCGWindowOwnerName"]
-						lengthOfBytesUsingEncoding:
-							NSUTF8StringEncoding]);
 
-				if (!name.empty()) {
-					title = name;
-				} else if (!owner.empty()) {
-					title = owner;
-				}
-				break;
+			if (layer != 0) {
+				continue;
 			}
+
+			std::string name([[app objectForKey:@"kCGWindowName"]
+						 UTF8String],
+					 [[app objectForKey:@"kCGWindowName"]
+						 lengthOfBytesUsingEncoding:
+							 NSUTF8StringEncoding]);
+			std::string owner(
+				[[app objectForKey:@"kCGWindowOwnerName"]
+					UTF8String],
+				[[app objectForKey:@"kCGWindowOwnerName"]
+					lengthOfBytesUsingEncoding:
+						NSUTF8StringEncoding]);
+
+			if (!name.empty()) {
+				title = name;
+			} else if (!owner.empty()) {
+				title = owner;
+			}
+
+			// Ignore the "StatusIndicator" application window
+			//
+			// It is used to display the microphone status and if active is
+			// always the top most window
+			if (title == "StatusIndicator") {
+				continue;
+			}
+
+			break;
 		}
 		apps = nil;
 		CFRelease(cfApps);
@@ -158,7 +170,7 @@ bool nameMachesPattern(std::string windowName, std::string pattern)
 		.contains(QRegularExpression(QString::fromStdString(pattern)));
 }
 
-bool isMaximized(const std::string &title)
+bool IsMaximized(const std::string &title)
 {
 	@autoreleasepool {
 		NSArray *screens = [NSScreen screens];
@@ -211,7 +223,7 @@ bool isWindowFullscreenOnScreen(NSDictionary *app, NSScreen *screen)
 	return NSEqualSizes(windowBounds.size, screenFrame.size);
 }
 
-bool isFullscreen(const std::string &title)
+bool IsFullscreen(const std::string &title)
 {
 	@autoreleasepool {
 		NSArray *screens = [NSScreen screens];
@@ -253,7 +265,13 @@ bool isFullscreen(const std::string &title)
 	return false;
 }
 
-int secondsSinceLastInput()
+std::optional<std::string> GetTextInWindow(const std::string &window)
+{
+	// Not implemented
+	return {};
+}
+
+int SecondsSinceLastInput()
 {
 	double time = CGEventSourceSecondsSinceLastEventType(
 			      kCGEventSourceStateCombinedSessionState,
@@ -310,7 +328,7 @@ void GetForegroundProcessName(QString &proc)
 	proc = QString::fromStdString(temp);
 }
 
-bool isInFocus(const QString &executable)
+bool IsInFocus(const QString &executable)
 {
 	std::string current;
 	GetForegroundProcessName(current);
@@ -453,3 +471,5 @@ void PressKeys(const std::vector<HotkeyType> keys, int duration)
 void PlatformCleanup() {}
 
 void PlatformInit() {}
+
+} // namespace advss
