@@ -3,6 +3,9 @@
 #include <string>
 #include <QStringList>
 #include <chrono>
+#include <optional>
+
+namespace advss {
 
 enum class HotkeyType;
 
@@ -14,12 +17,15 @@ extern std::chrono::high_resolution_clock::time_point lastMouseRightClickTime;
 void GetWindowList(std::vector<std::string> &windows);
 void GetWindowList(QStringList &windows);
 void GetCurrentWindowTitle(std::string &title);
-bool isFullscreen(const std::string &title);
-bool isMaximized(const std::string &title);
-int secondsSinceLastInput();
+bool IsFullscreen(const std::string &title);
+bool IsMaximized(const std::string &title);
+std::optional<std::string> GetTextInWindow(const std::string &window);
+int SecondsSinceLastInput();
 void GetProcessList(QStringList &processes);
 void GetForegroundProcessName(std::string &name);
-bool isInFocus(const QString &executable);
+bool IsInFocus(const QString &executable);
 void PressKeys(const std::vector<HotkeyType> keys, int duration);
 void PlatformInit();
 void PlatformCleanup();
+
+} // namespace advss
