@@ -1,5 +1,5 @@
 #include "status-control.hpp"
-#include "advanced-scene-switcher.hpp"
+#include "switcher-data.hpp"
 #include "utility.hpp"
 
 #include <obs-module.h>
@@ -7,6 +7,9 @@
 #include <QAction>
 #include <QToolBar>
 
+namespace advss {
+
+void OpenSettingsWindow();
 StatusDock *dock = nullptr;
 
 StatusControl::StatusControl(QWidget *parent, bool noLayout)
@@ -19,12 +22,17 @@ StatusControl::StatusControl(QWidget *parent, bool noLayout)
 			  "AdvSceneSwitcher.generalTab.status.currentStatus"),
 		  this))
 {
+	_statusPrefix->setWordWrap(true);
+	_statusPrefix->setSizePolicy(QSizePolicy::Expanding,
+				     QSizePolicy::Expanding);
 	_status->setStyleSheet("QLabel{ \
 		border-style: outset; \
 		border-width: 2px; \
 		border-radius: 7px; \
 		border-color: rgb(0,0,0,0) \
 		}");
+	_status->setSizePolicy(QSizePolicy::Maximum,
+			       QSizePolicy::MinimumExpanding);
 
 	QWidget::connect(_button, SIGNAL(clicked()), this,
 			 SLOT(ButtonClicked()));
@@ -32,8 +40,9 @@ StatusControl::StatusControl(QWidget *parent, bool noLayout)
 	if (!noLayout) {
 		QHBoxLayout *statusLayout = new QHBoxLayout();
 		statusLayout->addWidget(_statusPrefix);
-		statusLayout->addWidget(_status);
 		statusLayout->addStretch();
+		statusLayout->addWidget(_status);
+		statusLayout->setStretch(0, 10);
 		_buttonLayout->setContentsMargins(0, 0, 0, 0);
 		_buttonLayout->addWidget(_button);
 		QVBoxLayout *layout = new QVBoxLayout();
@@ -114,10 +123,9 @@ StatusDock::StatusDock(QWidget *parent) : OBSDock(parent)
 	QAction *action = new QAction;
 	action->setProperty("themeID", QVariant(QString::fromUtf8("cogsIcon")));
 	action->connect(action, &QAction::triggered, OpenSettingsWindow);
-	QIcon icon;
-	icon.addFile(
-		QString::fromUtf8(":/settings/images/settings/advanced.svg"),
-		QSize(), QIcon::Normal, QIcon::Off);
+	const auto path = QString::fromStdString(GetDataFilePath(
+		"res/images/" + GetThemeTypeName() + "Advanced.svg"));
+	QIcon icon(path);
 	action->setIcon(icon);
 
 	auto toolbar = new QToolBar;
@@ -141,6 +149,9 @@ StatusDock::StatusDock(QWidget *parent) : OBSDock(parent)
 	wrapper->setFrameShadow(QFrame::Sunken);
 	wrapper->setLayout(layout);
 	setWidget(wrapper);
+
+	setFloating(true);
+	hide();
 }
 
 void SetupDock()
@@ -149,5 +160,7 @@ void SetupDock()
 		static_cast<QMainWindow *>(obs_frontend_get_main_window()));
 	// Added for cosmetic reasons to avoid brief flash of dock window on startup
 	dock->setVisible(false);
-	static_cast<QAction *>(obs_frontend_add_dock(dock));
+	obs_frontend_add_dock(dock);
 }
+
+} // namespace advss
