@@ -1,11 +1,14 @@
 #pragma once
-#include <QDockWidget>
+#include "obs-dock.hpp"
+
 #include <QPushButton>
 #include <QLabel>
 #include <QTimer>
 #include <QLayout>
 #include <obs-data.h>
 
+namespace advss {
+
 class StatusControl : public QWidget {
 	Q_OBJECT
 
@@ -34,14 +37,6 @@ private:
 	bool _setToStopped = true;
 };
 
-// Only used to enable applying "OBSDock" stylesheet
-class OBSDock : public QDockWidget {
-	Q_OBJECT
-
-public:
-	inline OBSDock(QWidget *parent = nullptr) : QDockWidget(parent) {}
-};
-
 class StatusDock : public OBSDock {
 	Q_OBJECT
 
@@ -50,3 +45,5 @@ public:
 };
 
 void SetupDock();
+
+} // namespace advss
