@@ -2,9 +2,13 @@
 #include <curl/curl.h>
 #include <QLibrary>
 
+namespace advss {
+
 typedef CURL *(*initFunction)(void);
 typedef void (*cleanupFunction)(CURL *);
 typedef CURLcode (*setOptFunction)(CURL *, CURLoption, ...);
+typedef struct curl_slist *(*slistAppendFunction)(struct curl_slist *list,
+						  const char *string);
 typedef CURLcode (*performFunction)(CURL *);
 
 class Curlhelper {
@@ -13,6 +17,8 @@ public:
 	~Curlhelper();
 
 	template<typename... Args> CURLcode SetOpt(CURLoption, Args...);
+	struct curl_slist *SlistAppend(struct curl_slist *list,
+				       const char *string);
 	CURLcode Perform();
 	bool Initialized() { return _initialized; }
 
@@ -22,6 +28,7 @@ private:
 
 	initFunction _init = nullptr;
 	setOptFunction _setopt = nullptr;
+	slistAppendFunction _slistAppend = nullptr;
 	performFunction _perform = nullptr;
 	cleanupFunction _cleanup = nullptr;
 	CURL *_curl = nullptr;
@@ -37,3 +44,5 @@ inline CURLcode Curlhelper::SetOpt(CURLoption option, Args... args)
 	}
 	return _setopt(_curl, option, args...);
 }
+
+} // namespace advss
