@@ -1,10 +1,8 @@
 #pragma once
-
 #include "variable.hpp"
+#include "filter-combo-box.hpp"
 #include "utility.hpp"
 
-#include <QComboBox>
-
 namespace advss {
 
 class SourceSelection {
@@ -35,7 +33,7 @@ private:
 	friend class SourceSelectionWidget;
 };
 
-class SourceSelectionWidget : public QComboBox {
+class SourceSelectionWidget : public FilterComboBox {
 	Q_OBJECT
 
 public:
@@ -47,7 +45,7 @@ signals:
 	void SourceChanged(const SourceSelection &);
 
 private slots:
-	void SelectionChanged(const QString &name);
+	void SelectionChanged(int);
 	void ItemAdd(const QString &name);
 	void ItemRemove(const QString &name);
 	void ItemRename(const QString &oldName, const QString &newName);
