@@ -1,8 +1,7 @@
 #pragma once
+#include "filter-combo-box.hpp"
 #include "utility.hpp"
 
-#include <QComboBox>
-
 namespace advss {
 
 class TransitionSelection {
@@ -28,7 +27,7 @@ private:
 	friend class TransitionSelectionWidget;
 };
 
-class TransitionSelectionWidget : public QComboBox {
+class TransitionSelectionWidget : public FilterComboBox {
 	Q_OBJECT
 
 public:
