@@ -1,5 +1,7 @@
 #include "variable-text-edit.hpp"
-#include "switcher-data-structs.hpp"
+#include "switcher-data.hpp"
+
+namespace advss {
 
 VariableTextEdit::VariableTextEdit(QWidget *parent)
 	: ResizingPlainTextEdit(parent)
@@ -11,8 +13,10 @@ void VariableTextEdit::setPlainText(const QString &string)
 	QPlainTextEdit::setPlainText(string);
 }
 
-void VariableTextEdit::setPlainText(const VariableResolvingString &string)
+void VariableTextEdit::setPlainText(const StringVariable &string)
 {
 	QPlainTextEdit::setPlainText(
 		QString::fromStdString(string.UnresolvedValue()));
 }
+
+} // namespace advss
